@@ -39,7 +39,13 @@ $var_pag[11] = 'cashbox';
 $var_pag[12] = 'session_data';
 $var_pag[13] = 'cli_id';
 $var_pag[14] = 'priv_r';
-$n_var_pag = 15;
+$var_pag[15] = 'azione';
+$var_pag[16] = 'tipo_ic';
+$var_pag[17] = 'valore_xml';
+$var_pag[18] = 'token';
+$var_pag[19] = 'ord_ic';
+$var_pag[20] = 'tweb';
+$n_var_pag = 21;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -858,7 +864,7 @@ if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1")) {
 
 
-if ($azione == "pull_xml" and $tipo_ic == "boo" and $valore_xml and $token) {
+if ($azione == "pull_xml" and isset($tipo_ic) and $tipo_ic == "boo" and !empty($valore_xml) and !empty($token)) {
 
 $file_interconnessioni = C_DATI_PATH."/dati_interconnessioni.php";
 if (@is_file($file_interconnessioni)) {
@@ -869,14 +875,14 @@ $funz_import_reservations = "";
 
 $interconn_dir = opendir("./includes/interconnect/");
 while ($mod_ext = readdir($interconn_dir)) {
-if ($mod_ext != "." and $mod_ext != ".." and $mod_ext == $tipo_ic.$ord_ic and @is_dir("./includes/interconnect/$mod_ext")) {
+if ($mod_ext != "." and $mod_ext != ".." and $mod_ext == $tipo_ic.fixset($ord_ic) and @is_dir("./includes/interconnect/$mod_ext")) {
 include("./includes/interconnect/$mod_ext/name.php");
 if ($ic_present[$interconnection_name] == "SI") {
 include("./includes/interconnect/$mod_ext/functions_import.php");
 $funz_import_reservations = "import_reservations_".$interconnection_func_name;
 } # fine if ($ic_present[$interconnection_name] == "SI")
 break;
-} # fine if ($mod_ext != "." and $mod_ext != ".." and $mod_ext == $tipo_ic.$ord_ic and...
+} # fine if ($mod_ext != "." and $mod_ext != ".." and $mod_ext == $tipo_ic.fixset($ord_ic) and...
 } # fine while ($mod_ext = readdir($interconn_dir))
 closedir($interconn_dir);
 if ($funz_import_reservations) {
@@ -922,7 +928,7 @@ $id_utente = $id_utente_origi;
 } # fine if ($funz_import_reservations)
 } # fine if (@is_array($ic_present))
 } # fine if (@is_file($file_interconnessioni))
-} # fine if ($azione == "pull_xml" and $tipo_ic == "boo" and $valore_xml and $token)
+} # fine if ($azione == "pull_xml" and isset($tipo_ic) and $tipo_ic == "boo" and !empty($valore_xml) and !empty($token))
 
 
 } # fine if ($REMOTE_ADDR == C_IP_MOD_EXT_CARTE_CREDITO or ($REMOTE_ADDR == "::1" and C_IP_MOD_EXT_CARTE_CREDITO == "127.0.0.1"))
