@@ -45,7 +45,20 @@ $var_pag[16] = 'mostra_header';
 $var_pag[17] = 'salva_backup';
 $var_pag[18] = 'includi_modelli';
 $var_pag[19] = 'cancella_backup';
-$n_var_pag = 20;
+$var_pag[20] = 'utente_backup';
+$var_pag[21] = 'lista_anni_passa';
+$n_var_pag = 22;
+if (isset($_REQUEST['lista_anni_passa'])) $num2 = $_REQUEST['lista_anni_passa'];
+else $num2 = 0;
+if ($num2) {
+$num2 = explode(",",$num2);
+$num3 = count($num2);
+for ($num1 = 1 ; $num1 < $num3 ; $num1++) {
+$num4 = (int) $num2[$num1];
+$var_pag[$n_var_pag++] = "anno_sel$num4";
+} # fine for $num1
+} # fine if ($num2)
+
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -61,10 +74,12 @@ $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $tablecache = $PHPR_TAB_PRE."cache";
 
-if (defined("C_UTENTE_BACKUP_ESTERNO") and C_UTENTE_BACKUP_ESTERNO != "" and $utente_backup == C_UTENTE_BACKUP_ESTERNO and (!defined('C_VERSIONE_ATTUALE') or !defined('C_PHPR_VERSIONE_NUM') or (double) C_VERSIONE_ATTUALE == (double) C_PHPR_VERSIONE_NUM)) $id_utente = "b";
+if (defined("C_UTENTE_BACKUP_ESTERNO") and C_UTENTE_BACKUP_ESTERNO != "" and isset($utente_backup) and $utente_backup == C_UTENTE_BACKUP_ESTERNO and (!defined('C_VERSIONE_ATTUALE') or !defined('C_PHPR_VERSIONE_NUM') or (double) C_VERSIONE_ATTUALE == (double) C_PHPR_VERSIONE_NUM)) $id_utente = "b";
 else $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 if ($id_utente) {
 
+$privilegi_annuali_utente = null;
+$privilegi_globali_utente = null;
 if ($id_utente != 1 and $id_utente != "b") {
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
@@ -72,8 +87,6 @@ else $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 $priv_crea_backup = substr($priv_mod_pers,1,1);
-chiudi_query($privilegi_annuali_utente);
-chiudi_query($privilegi_globali_utente);
 } # fine if ($id_utente != 1 and $id_utente != "b")
 else {
 $priv_crea_backup = "s";
@@ -96,6 +109,8 @@ $titolo = "HotelDruid: ".mex("Backup",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 } # fine if (fixset($mostra_header) != "NO")
+if ($privilegi_annuali_utente) chiudi_query($privilegi_annuali_utente);
+if ($privilegi_globali_utente) chiudi_query($privilegi_globali_utente);
 
 
 
@@ -135,11 +150,11 @@ $cond_ic_e_priv = "";
 if (!empty($anni_backup)) {
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_reg = risul_query($anni,$num1,'idanni');
-if (${'anno_sel'.$anno_reg}) {
+if (!empty(${'anno_sel'.$anno_reg})) {
 if (!$cond_anni) $cond_anni = "where ";
 else $cond_anni .= " or ";
 $cond_anni .= "idanni = '$anno_reg'";
-} # fine if (${'anno_sel'.$anno_reg})
+} # fine if (!empty(${'anno_sel'.$anno_reg}))
 else {
 if (!$cond_personalizza) $cond_personalizza = "where ";
 else $cond_personalizza .= " and ";
@@ -147,8 +162,7 @@ $cond_personalizza .= "idpersonalizza != 'giorno_vedi_ini_sett$anno_reg'";
 if (!$cond_ic_e_priv) $cond_ic_e_priv = "where ";
 else $cond_ic_e_priv .= " and ";
 $cond_ic_e_priv .= "anno != '$anno_reg'";
-
-} # fine else if (${'anno_sel'.$anno_reg})
+} # fine else if (!empty(${'anno_sel'.$anno_reg}))
 } # fine for $num1
 if (!$cond_anni) $anni_backup = "";
 } # fine if (!empty($anni_backup))
@@ -278,13 +292,13 @@ if (@is_file(C_DATI_PATH."/dati_interconnessioni.php")) dump_testo("/dati_interc
 if (@is_file(C_DATI_PATH."/log_utenti.php")) dump_testo("/log_utenti.php",$file);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_reg = risul_query($anni,$num1,'idanni');
-if (empty($anni_backup) or ${'anno_sel'.$anno_reg}) {
+if (empty($anni_backup) or !empty(${'anno_sel'.$anno_reg})) {
 for ($num2 = 0 ; $num2 < numlin_query($utenti) ; $num2++) {
 $idutente_reg = risul_query($utenti,$num2,'idutenti');
 if (@is_file(C_DATI_PATH."/selectperiodi$anno_reg.$idutente_reg.php")) dump_testo("/selectperiodi$anno_reg.$idutente_reg.php",$file);
 if (@is_file(C_DATI_PATH."/selperiodimenu$anno_reg.$idutente_reg.php")) dump_testo("/selperiodimenu$anno_reg.$idutente_reg.php",$file);
 } # fine for $num2
-} # fine if (empty($anni_backup) or ${'anno_sel'.$anno_reg})
+} # fine if (empty($anni_backup) or !empty(${'anno_sel'.$anno_reg}))
 } # fine for $num1
 
 fwrite($file,"<database>
@@ -319,7 +333,7 @@ dump_tabella("interconnessioni",$file,$cond_ic_e_priv);
 dump_tabella("messaggi",$file);
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_reg = risul_query($anni,$num1,'idanni');
-if (empty($anni_backup) or ${'anno_sel'.$anno_reg}) {
+if (empty($anni_backup) or !empty(${'anno_sel'.$anno_reg})) {
 dump_tabella("prenota$anno_reg",$file);
 dump_tabella("prenotacanc$anno_reg",$file);
 dump_tabella("costiprenota$anno_reg",$file);
@@ -329,7 +343,7 @@ dump_tabella("ntariffe$anno_reg",$file);
 dump_tabella("regole$anno_reg",$file);
 dump_tabella("soldi$anno_reg",$file);
 dump_tabella("costi$anno_reg",$file);
-} # fine if (empty($anni_backup) or ${'anno_sel'.$anno_reg})
+} # fine if (empty($anni_backup) or !empty(${'anno_sel'.$anno_reg}))
 } # fine for $num1
 fwrite($file,"</database>
 ");
@@ -907,6 +921,7 @@ echo " (".mex("sovrascrivendo l'attuale",$pag)." ".mex("creato il",$pag)." $data
 echo ".<br><table><tr><td style=\"width: 30px;\"></td><td>";
 $anni = esegui_query("select * from $tableanni order by idanni");
 $num_anni = numlin_query($anni);
+$lista_anni = "";
 if ($num_anni > 1) {
 echo "<div><label><input type=\"radio\" name=\"anni_backup\" value=\"\" checked>".mex("Includi tutti gli anni",$pag)."</label></div>
 <div onclick=\"document.getElementById('ab_sel').checked='1'\"><label><input type=\"radio\" name=\"anni_backup\" id=\"ab_sel\" value=\"sel\">".mex("Includi solo gli anni selezionati",$pag)."</label>: ";
@@ -914,10 +929,12 @@ for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 $anno_corr = risul_query($anni,$num1,'idanni');
 echo "<label><input type=\"checkbox\" name=\"anno_sel$anno_corr\" value=\"1\"> $anno_corr</label>";
 if ($num1 != ($num_anni - 1)) echo "; ";
+$lista_anni .= ",$anno_corr";
 } # fine for $num1
 echo "</div>";
 } # fine if ($num_anni > 1)
-echo "<label><input type=\"checkbox\" name=\"includi_modelli\" value=\"SI\" checked> ".mex("Includi le pagine per il sito web",$pag)."</label>
+echo "<input type=\"hidden\" name=\"lista_anni_passa\" value=\"$lista_anni\">
+<label><input type=\"checkbox\" name=\"includi_modelli\" value=\"SI\" checked> ".mex("Includi le pagine per il sito web",$pag)."</label>
 </td></tr></table></div></form>
 <table><tr><td style=\"height: 8px;\"></td></tr></table>";
 
