@@ -41,7 +41,8 @@ $var_pag[11] = 'numletti';
 $var_pag[12] = 'creabase';
 $var_pag[13] = 'lingua';
 $var_pag[14] = 'insappartamenti';
-$n_var_pag = 15;
+$var_pag[15] = 'lista_camere_letti';
+$n_var_pag = 16;
 $num2 = 0;
 if (isset($_POST['numappartamenti'])) $num2 = (int) $_POST['numappartamenti'];
 elseif (isset($_GET['numappartamenti'])) $num2 = (int) $_GET['numappartamenti'];
@@ -312,6 +313,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_doc_salvati','1','100')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_storia_soldi','1','200')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_data','1','europa')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('stile_nomi','1','ma1or')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_categorie_persone','1','1')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('minuti_durata_sessione','1','90')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('usa_cookies','1','0')");
