@@ -48,7 +48,24 @@ $var_pag[20] = 'nor3m';
 $var_pag[21] = 'nor3';
 $var_pag[22] = 'id_utente_inserimento';
 $var_pag[23] = 'regola_4';
-$n_var_pag = 24;
+$var_pag[24] = 'cancella_vecchie_regole';
+$var_pag[25] = 'num_creg_passa';
+$var_pag[26] = 'canc_regola_1';
+$var_pag[27] = 'gia_stato';
+$var_pag[28] = 'regola_2b';
+$var_pag[29] = 'num_giorni';
+$var_pag[30] = 'ini_fine';
+$n_var_pag = 31;
+$num2 = 0;
+if (isset($_POST['num_creg_passa'])) $num2 = (int) $_POST['num_creg_passa'];
+elseif (isset($_GET['num_creg_passa'])) $num2 = (int) $_GET['num_creg_passa'];
+for ($num1 = 0 ; $num1 < $num2 ; $num1++) {
+$var_pag[$n_var_pag++] = "nome_creg_passa$num1";
+$num3 = 0;
+if (isset($_POST["nome_creg_passa$num1"])) $num3 = (int) $_POST["nome_creg_passa$num1"];
+elseif (isset($_GET["nome_creg_passa$num1"])) $num3 = (int) $_GET["nome_creg_passa$num1"];
+if ($num3) $var_pag[$n_var_pag++] = "creg$num3";
+} # fine if for $num1
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -273,9 +290,9 @@ $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 if (!empty($regola_1) and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "a")) {
 $regola_1_tar = "";
-if (!$inizioperiodo or !$fineperiodo or !$appartamento) {
+if (empty($inizioperiodo) or empty($fineperiodo) or empty($appartamento)) {
 echo mex("Non sono stati inseriti tutti i dati necessari",$pag)."!<br>";
-} # fine if (!$inizioperiodo or !$fineperiodo or !$appartamento)
+} # fine if (empty($inizioperiodo) or empty($fineperiodo) or empty($appartamento))
 else {
 $idinizioperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '".aggslashdb($inizioperiodo)."' ");
 if (numlin_query($idinizioperiodo) == 0) $idinizioperiodo = 9999999;
@@ -319,16 +336,16 @@ echo mex("Esiste già una regola di questo tipo nell'appartamento e nel periodo
 <input type=\"hidden\" name=\"cancella_vecchie_regole\" value=\"1\">
 <input type=\"hidden\" name=\"chiudi_app\" value=\"".htmlspecialchars(fixstr($chiudi_app))."\">
 <input type=\"hidden\" name=\"appartamento\" value=\"$appartamento\">
-<input type=\"hidden\" name=\"inizioperiodo\" value=\"".htmlspecialchars(fixstr($inizioperiodo))."\">
-<input type=\"hidden\" name=\"fineperiodo\" value=\"".htmlspecialchars(fixstr($fineperiodo))."\">
+<input type=\"hidden\" name=\"inizioperiodo\" value=\"".htmlspecialchars($inizioperiodo)."\">
+<input type=\"hidden\" name=\"fineperiodo\" value=\"".htmlspecialchars($fineperiodo)."\">
 <input type=\"hidden\" name=\"motivazione\" value=\"".htmlspecialchars(fixstr($motivazione))."\">
 <em>".mex("Regole esistenti",$pag)."</em>:<br>";
 for ($num1 = 0 ; $num1 < $num_vecchia_regola ; $num1++) {
 $idregola_v = risul_query($vecchia_regola,$num1,'idregole');
 $iddatainizio_v = risul_query($vecchia_regola,$num1,'iddatainizio');
 $iddatafine_v = risul_query($vecchia_regola,$num1,'iddatafine');
-$motivazione_v = risul_query($vecchia_regola,$num1,'motivazione');
-$motivazione2_v = risul_query($vecchia_regola,$num1,'motivazione2');
+$motivazione_v = (string) risul_query($vecchia_regola,$num1,'motivazione');
+$motivazione2_v = (string) risul_query($vecchia_regola,$num1,'motivazione2');
 $datainizio_v = esegui_query("select datainizio from $tableperiodi where idperiodi = '$iddatainizio_v' ");
 $datainizio_v = formatta_data(risul_query($datainizio_v,0,'datainizio'),$stile_data);
 $datafine_v = esegui_query("select datafine from $tableperiodi where idperiodi = '$iddatafine_v' ");
@@ -341,12 +358,13 @@ if (strcmp(trim($motivazione_v),"")) echo " (<em>$motivazione_v</em>)";
 if ($attiva_regole1_consentite == "n") {
 echo ".<select name=\"creg$idregola_v\">";
 if ($iddatainizio_v < $idinizioperiodo or $iddatafine_v > $idfineperiodo) echo "<option value=\"\" selected>".mex("Ridimensiona",$pag)."</option>";
-echo "<option value=\"1\">".mex("Cancella",$pag)."</option></select>";
+echo "<option value=\"1\">".mex("Cancella",$pag)."</option></select><input type=\"hidden\" name=\"nome_creg_passa$num1\" value=\"$idregola_v\">";
 } # fine if ($attiva_regole1_consentite == "n")
 echo "<br>";
 } # fine for $num1
 if ($attiva_regole1_consentite == "n") echo "<button class=\"cont\" type=\"submit\"><div>".mex("Cancella o ridimensiona queste regole",$pag)."</div></button>";
-echo "<br><br><br></div></form>";
+echo "<input type=\"hidden\" name=\"num_creg_passa\" value=\"$num_vecchia_regola\">
+<br><br><br></div></form>";
 } # fine if ($num_vecchia_regola != 0 and empty($cancella_vecchie_regole))
 else {
 $idregole = esegui_query("select max(idregole) from $tableregole");
@@ -454,14 +472,14 @@ unlock_tabelle($tabelle_lock);
 } # fine else if (!numlin_query($app_esistente))
 } # fine else if ($motivazione == " ")
 } # fine else if ($idfineperiodo < $idinizioperiodo)
-} # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
+} # fine else if (empty($inizioperiodo) or empty($fineperiodo) or empty($appartamento))
 } # fine if (!empty($regola_1) and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "a"))
 
 
 if (!empty($regola_1_tar) and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "t")) {
-if (!$inizioperiodo or !$fineperiodo or !$tipotariffa or substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
+if (empty($inizioperiodo) or empty($fineperiodo) or empty($tipotariffa) or substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
 echo mex("Non sono stati inseriti tutti i dati necessari",$pag)."!<br>";
-} # fine if (!$inizioperiodo or !$fineperiodo or !$tipotariffa or...
+} # fine if (empty($inizioperiodo) or empty($fineperiodo) or empty($tipotariffa) or...
 else {
 $idinizioperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '".aggslashdb($inizioperiodo)."' ");
 if (numlin_query($idinizioperiodo) == 0) $idinizioperiodo = 9999999;
@@ -488,7 +506,7 @@ if ($mod_idregola1) $cond_reg_mod = " and idregole != '$mod_idregola1'";
 else $cond_reg_mod = "";
 $vecchia_regola = esegui_query("select * from $tableregole where tariffa_chiusa = '$tipotariffa' and iddatainizio <= '$idfineperiodo' and iddatafine >= '$idinizioperiodo'$cond_reg_mod order by iddatainizio ");
 $num_vecchia_regola = numlin_query($vecchia_regola);
-if ($num_vecchia_regola != 0 and !$cancella_vecchie_regole) {
+if ($num_vecchia_regola != 0 and empty($cancella_vecchie_regole)) {
 $tariffa_vedi = mex("tariffa","prenota.php").substr($tipotariffa,7);
 echo mex("Esiste già una regola di questo tipo nel periodo selezionato",$pag)." (".formatta_data($inizioperiodo,$stile_data)." ".mex("al",$pag)." ".formatta_data($fineperiodo,$stile_data).").<br><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div class=\"linhbox\">
@@ -497,12 +515,12 @@ echo mex("Esiste già una regola di questo tipo nel periodo selezionato",$pag)."
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <input type=\"hidden\" name=\"regola_1_tar\" value=\"1\">
 <input type=\"hidden\" name=\"mod_idregola1\" value=\"$mod_idregola1\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
 <input type=\"hidden\" name=\"cancella_vecchie_regole\" value=\"1\">
 <input type=\"hidden\" name=\"tipotariffa\" value=\"$tipotariffa\">
 <input type=\"hidden\" name=\"inizioperiodo\" value=\"".htmlspecialchars($inizioperiodo)."\">
 <input type=\"hidden\" name=\"fineperiodo\" value=\"".htmlspecialchars($fineperiodo)."\">
-<input type=\"hidden\" name=\"motivazione\" value=\"".htmlspecialchars($motivazione)."\">
+<input type=\"hidden\" name=\"motivazione\" value=\"".htmlspecialchars(fixstr($motivazione))."\">
 <em>".mex("Regole esistenti",$pag)."</em>:<br>";
 for ($num1 = 0 ; $num1 < $num_vecchia_regola ; $num1++) {
 $idregola_v = risul_query($vecchia_regola,$num1,'idregole');
@@ -518,11 +536,12 @@ if (strcmp(trim($motivazione_v),"")) echo " (<em>$motivazione_v</em>)";
 echo ".<select name=\"creg$idregola_v\">";
 if ($iddatainizio_v < $idinizioperiodo or $iddatafine_v > $idfineperiodo) echo "<option value=\"\" selected>".mex("Ridimensiona",$pag)."</option>";
 echo "<option value=\"1\">".mex("Cancella",$pag)."</option>
-</select><br>";
+</select><input type=\"hidden\" name=\"nome_creg_passa$num1\" value=\"$idregola_v\"><br>";
 } # fine for $num1
 echo "<button class=\"cont\" type=\"submit\"><div>".mex("Cancella o ridimensiona queste regole",$pag)."</div></button>
+<input type=\"hidden\" name=\"num_creg_passa\" value=\"$num_vecchia_regola\">
 <br><br><br></div></form>";
-} # fine if ($num_vecchia_regola != 0 and !$cancella_vecchie_regole)
+} # fine if ($num_vecchia_regola != 0 and empty($cancella_vecchie_regole))
 else {
 $idregole = esegui_query("select max(idregole) from $tableregole");
 $idregole = risul_query($idregole,0,0);
@@ -570,10 +589,10 @@ esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_trans
 values ('$id_transazione','$id_sessione','cr_1t','$anno','".aggslashdb($inizioperiodo)."','".aggslashdb($fineperiodo)."','".aggslashdb($motivazione)."','".aggslashdb($tipotariffa)."','$ultimo_accesso')");
 } # fine else if (numlin_query($transaz_esistente))
 unlock_tabelle($tabelle_lock);
-} # fine else if ($num_vecchia_regola != 0 and !$cancella_vecchie_regole)
+} # fine else if ($num_vecchia_regola != 0 and empty($cancella_vecchie_regole))
 } # fine else if ($motivazione == " ")
 } # fine else if ($idfineperiodo < $idinizioperiodo)
-} # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
+} # fine else if (empty($inizioperiodo) or empty($fineperiodo) or empty($tipotariffa) or...
 } # fine if (!empty($regola_1_tar) and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "t"))
 
 
@@ -590,12 +609,12 @@ break;
 } # fine for $numtariffa
 } # fine if ($attiva_tariffe_consentite != "n")
 if ($tutte_tar_consentite) {
-if ($gia_stato) {
+if (!empty($gia_stato)) {
 esegui_query("delete from $tableregole where (app_agenzia != '' and app_agenzia is not NULL) or (tariffa_chiusa != '' and tariffa_chiusa is not NULL) ");
 echo mex("Le regole sono state cancellate",$pag);
 $aggiorna_ic_disp = 1;
 $aggiorna_ic_tar = 1;
-} # fine if ($gia_stato)
+} # fine if (!empty($gia_stato))
 else {
 echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
@@ -604,7 +623,7 @@ echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
 <input type=\"hidden\" name=\"inserisci\" value=\"SI\">
 <input type=\"hidden\" name=\"canc_regola_1\" value=\"1\">
 <button class=\"crul\" type=\"submit\" name=\"gia_stato\" value=\"1\"><div>  ".mex("SI",$pag)."  </div></button></div></form><br>";
-} # fine else if ($gia_stato)
+} # fine else if (!empty($gia_stato))
 } # fine if ($tutte_tar_consentite)
 } # fine if (!empty($canc_regola_1) and $priv_mod_reg1 == "s" and $tutti_app_consentiti and $attiva_regole1_consentite == "n")
 
@@ -613,6 +632,7 @@ if ((!empty($regola_2) or !empty($regola_2b)) and $priv_mod_reg2 == "s") {
 if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
 $inserire = "NO";
 echo "<br><span class=\"colwarn\">".mex("Si deve scegliere la tariffa",$pag)."</span>.<br><br>";
+$num_regole_esistente = 0;
 } # fine if (substr($tipotariffa,0,7) != "tariffa" or...
 else {
 $regola_esistente = esegui_query("select * from $tableregole where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
@@ -624,10 +644,11 @@ echo mex("La tariffa scelta ha già degli appartamenti associati, cancella la re
 } # fine if ($num_regole_esistente != 0)
 */
 } # fine else if (substr($tipotariffa,0,7) != "tariffa" or...
-if (!$lista_app) {
+$num_app_reali = 0;
+if (empty($lista_app)) {
 $inserire = "NO";
 echo "<br><span class=\"colwarn\">".mex("Si deve inserire almeno un appartamento da associare",'unit.php')."</span>.<br><br>";
-} # fine if (!$lista_app)
+} # fine if (empty($lista_app))
 else {
 if ($num_regole_esistente) {
 if (!empty($regola_2b)) $reg_corr = risul_query($regola_esistente,0,'motivazione2');
@@ -643,22 +664,21 @@ if ($appartamenti_consentiti[$appartamento] == "SI" or strstr(",$reg_corr,",",$a
 } # fine for $num1
 $vett_app = explode(",",$lista_app);
 $num_app = count($vett_app);
-$num_app_reali = 0;
 $app_trovato = array();
 for ($num1 = 0 ; $num1 < $num_app ; $num1 = $num1 + 1) {
-if ($app_esistente[$vett_app[$num1]] != "SI") {
+if (!isset($app_esistente[$vett_app[$num1]]) or $app_esistente[$vett_app[$num1]] != "SI") {
 $inserire = "NO";
 echo "<br>".mex("L'appartamento",'unit.php')." <b class=\"colwarn\">".htmlspecialchars($vett_app[$num1])."</b>".mex(" non esiste",$pag).".<br><br>";
-} # fine if ($app_esistente[$appartamento] != "SI")
+} # fine if (!isset($app_esistente[$vett_app[$num1]]) or $app_esistente[$appartamento] != "SI")
 else {
 if (!empty($app_trovato[$vett_app[$num1]])) $lista_app = substr(str_replace(",".$vett_app[$num1].",",",",",$lista_app,"),1,-1).",".$vett_app[$num1];
 else $num_app_reali++;
 $app_trovato[$vett_app[$num1]] = 1;
-} # fine else if ($app_esistente[$appartamento] != "SI")
+} # fine else if (!isset($app_esistente[$vett_app[$num1]]) or $app_esistente[$appartamento] != "SI")
 } # fine for $num1
-} # fine else if (!$lista_app)
+} # fine else if (empty($lista_app))
 $num_da_assegnare = 1;
-if ($regola_2) {
+if (!empty($regola_2)) {
 $num_da_assegnare = $num_apti;
 if ($num_apti < 1 or $num_apti > $num_appartamenti) $inserire = "NO";
 if ($num_regole_esistente) {
@@ -669,9 +689,9 @@ $num_regola_2b_esist = count($num_regola_2b_esist);
 if ($num_regola_2b_esist < $num_app_reali) $num_app_reali = $num_regola_2b_esist;
 } # fine if if (strcmp((string) $regola_2b_esist,""))
 } # fine if ($num_regole_esistente)
-} # fine if ($regola_2)
+} # fine if (!empty($regola_2))
 elseif ($num_regole_esistente) {
-$num_da_assegnare = risul_query($regola_esistente,0,'motivazione3');
+$num_da_assegnare = (string) risul_query($regola_esistente,0,'motivazione3');
 if (substr($num_da_assegnare,0,1) == "v") $num_da_assegnare = substr($num_da_assegnare,1);
 } # fine elseif ($num_regole_esistente)
 if ($num_da_assegnare and $num_da_assegnare > $num_app_reali and $inserire != "NO") {
@@ -693,7 +713,7 @@ $num_giorni_ini = "NULL";
 $num_giorni_fine = "'$num_giorni'";
 } # fine if ($ini_fine == "fine")
 } # fine if (!empty($regola_2b))
-if ($v_apti != "v") $v_apti = "";
+if (!isset($v_apti) or $v_apti != "v") $v_apti = "";
 
 if (!isset($inserire) or $inserire != "NO") {
 if ($num_regole_esistente != 0) {
