@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -36,6 +36,7 @@ $altre_tab_lock = array($tableanni,$tableprenota,$tablecostiprenota,$tableperiod
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $num_r = 0;
 $lista_p = array();
+$ultima_ripetizione_cliente = array();
 for ($num1 = 1 ; $num1 <= $num_ripeti ; $num1++) {
 $id_prenota = aggslashdb($lista_prenota[$num1]);
 $dati_prenota = esegui_query("select * from $tableprenota where idprenota = '$id_prenota'");
@@ -54,8 +55,11 @@ $lista_p[$num_r] = $lista_prenota[$num1];
 if ($priv_mod_utente_ins != "n") ${"utente_inserimento_prenotazione_".$num_r} = $utente_inserimento;
 ${"data_inserimento_prenotazione_".$num_r} = substr(risul_query($dati_prenota,0,'datainserimento'),0,16);
 if ($vedi_clienti != "NO") {
-$id_clienti = risul_query($dati_prenota,0,'idclienti');
-$dati_cliente = esegui_query("select * from $tableclienti where idclienti = '$id_clienti' ");
+${"numero_cliente_".$num_r} = risul_query($dati_prenota,0,'idclienti');
+if (!empty($ultima_ripetizione_cliente[${"numero_cliente_".$num_r}])) ${"ultima_prenotazione_per_cliente_".$ultima_ripetizione_cliente[${"numero_cliente_".$num_r}]} = 0;
+$ultima_ripetizione_cliente[${"numero_cliente_".$num_r}] = $num_r;
+${"ultima_prenotazione_per_cliente_".$num_r} = 1;
+$dati_cliente = esegui_query("select * from $tableclienti where idclienti = '".${"numero_cliente_".$num_r}."' ");
 if ($vedi_clienti == "PROPRI" or $vedi_clienti == "GRUPPI") {
 $mostra_cliente = "SI";
 $utente_inserimento = risul_query($dati_cliente,0,'utente_inserimento');
@@ -100,7 +104,7 @@ if (strcmp((string) risul_query($dati_cliente,0,'email3'),"")) ${"email_certific
 } # fine if ($priv_vedi_telefoni == "s")
 if (strcmp((string) risul_query($dati_cliente,0,'cod_fiscale'),"")) ${"codice_fiscale_".$num_r} = risul_query($dati_cliente,0,'cod_fiscale');
 if (strcmp((string) risul_query($dati_cliente,0,'partita_iva'),"")) ${"partita_iva_".$num_r} = risul_query($dati_cliente,0,'partita_iva');
-$dati_relcliente = esegui_query("select * from $tablerelclienti where idclienti = '$id_clienti' and tipo = 'campo_pers' ");
+$dati_relcliente = esegui_query("select * from $tablerelclienti where idclienti = '".${"numero_cliente_".$num_r}."' and tipo = 'campo_pers' ");
 $num_dati_relcliente = numlin_query($dati_relcliente);
 for ($num2 = 0 ; $num2 < $num_dati_relcliente ; $num2++) {
 ${"campo_personalizzato_".risul_query($dati_relcliente,$num2,'testo1')."_".$num_r} = risul_query($dati_relcliente,$num2,'testo3');
@@ -112,12 +116,13 @@ chiudi_query($dati_cliente);
 ${"numero_prenotazione_".$num_r} = $id_prenota;
 if ($priv_mod_codice == "s") {
 $cod_prenota = risul_query($dati_prenota,0,'codice');
-${"codice_prenotazione_".$num_r} = substr($cod_prenota,0,2).$id_clienti.substr($cod_prenota,2,1).$id_prenota.substr($anno,-1).substr($cod_prenota,-1);
+${"codice_prenotazione_".$num_r} = substr($cod_prenota,0,2).${"numero_cliente_".$num_r}.substr($cod_prenota,2,1).$id_prenota.substr($anno,-1).substr($cod_prenota,-1);
 } # fine if ($priv_mod_codice == "s")
 $id_data_inizio = risul_query($dati_prenota,0,'iddatainizio');
 $id_data_fine = risul_query($dati_prenota,0,'iddatafine');
 ${"data_fine_".$num_r} = esegui_query("select * from $tableperiodi where idperiodi = '$id_data_fine'");
 ${"data_fine_".$num_r} = risul_query(${"data_fine_".$num_r},0,'datafine');
+${"unita_occupata_".$num_r} = risul_query($dati_prenota,0,'idappartamenti');
 
 if ($id_data_inizio) {
 ${"data_inizio_".$num_r} = esegui_query("select * from $tableperiodi where idperiodi = '$id_data_inizio'");
@@ -140,7 +145,7 @@ ${"valuta_tariffa_".$num_r} = $valuta_tariffa[0];
 ${"costo_valuta_tariffa_".$num_r} = converti_valuta($costo_tariffa,$valuta_tariffa[1],$valuta_tariffa[2]);
 } # fine if ($valuta_tariffa)
 $tariffesettimanali = risul_query($dati_prenota,0,'tariffesettimanali');
-${"percentuale_tasse_tariffa_".$num_r} = 0;
+${"percentuale_tasse_tariffa_".$num_r} = "0";
 if ($priv_mod_tariffa != "n") {
 ${"nome_tariffa_".$num_r} = $tariffa[0];
 if ($priv_mod_tariffa != "p") ${"costo_tariffa_".$num_r} = $costo_tariffa;
@@ -183,11 +188,13 @@ if (strcmp((string) $numpersone,"")) ${"num_persone_".$num_r} = $numpersone;
 $cat_persone = dati_cat_pers_p($dati_prenota,0,$dati_cat_pers,$numpersone,$lingua_mex,0);
 for ($num2 = 0 ; $num2 < $dati_cat_pers['num'] ; $num2++) {
 if (!empty($cat_persone[$num2]['esist'])) ${"num_persone_tipo_".($num2 + 1)."_".$num_r} = $cat_persone[$cat_persone[$num2]['ncp']]['molt'];
-else ${"num_persone_tipo_".($num2 + 1)."_".$num_r} = 0;
+else ${"num_persone_tipo_".($num2 + 1)."_".$num_r} = "0";
 } # fine for $num2
-${"unita_occupata_".$num_r} = risul_query($dati_prenota,0,'idappartamenti');
 ${"unita_assegnabili_".$num_r} = risul_query($dati_prenota,0,'app_assegnabili');
-if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i") ${"pagato_".$num_r} = risul_query($dati_prenota,0,'pagato');
+$pagato = risul_query($dati_prenota,0,'pagato');
+if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i") ${"pagato_".$num_r} = $pagato;
+if ($pagato or substr((string) risul_query($dati_prenota,0,'conferma'),0,1) == "S") ${"conferma_".$num_r} = 1;
+else ${"conferma_".$num_r} = "";
 $num_letti_agg = array('max' => 0);
 $costo_agg_tot = (double) 0;
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota,$dati_cat_pers);
@@ -197,17 +204,17 @@ $costo_agg_parziale = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$id_
 $costo_agg_tot = (double) $costo_agg_tot + $costo_agg_parziale;
 if ($priv_mod_costi_agg != "n") {
 ${"nome_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['nome'];
-${"percentuale_tasse_costo_agg".$numca."_".$num_r} = 0;
+${"percentuale_tasse_costo_agg".$numca."_".$num_r} = "0";
 if ($priv_mod_costi_agg != "p") {
 ${"val_costo_agg".$numca."_".$num_r} = $costo_agg_parziale;
-if (strcmp((string) $dati_cap[$numca]['tasseperc'],"")) ${"percentuale_tasse_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['tasseperc'];
+if (strcmp((string) $dati_cap[$numca]['tasseperc'],"")) ${"percentuale_tasse_costo_agg".$numca."_".$num_r} = (string) $dati_cap[$numca]['tasseperc'];
 ${"valore_giornaliero_max_costo_agg".$numca."_".$num_r} = $prezzi_giorn_costo;
 } # fine if ($priv_mod_costi_agg != "p")
 ${"moltiplica_max_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['moltiplica_costo'];
-if ($dati_cap[$numca]['associasett'] == "s") {
-if ($dati_cap[$numca]['settimane']) ${"giorni_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['settimane'];
-else ${"giorni_costo_agg".$numca."_".$num_r} = ",";
-} # fine if ($dati_cap[$numca]['associasett'] == "s")
+if ($dati_cap[$numca]['tipo'] == "s") {
+if ($dati_cap[$numca]['associasett'] == "s" and !$dati_cap[$numca]['settimane']) ${"giorni_costo_agg".$numca."_".$num_r} = ",";
+else ${"giorni_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['settimane'];
+} # fine if ($dati_cap[$numca]['tipo'] == "s")
 else ${"giorni_costo_agg".$numca."_".$num_r} = "";
 if ($dati_cap[$numca]['letto'] == "s" and $dati_cat_pers['num'] and $dati_cap[$numca]['cat_pers']['esist'][0]) ${"tipo_persona_costo_agg".$numca."_".$num_r} = ($dati_cap[$numca]['cat_pers']['ord'][0] + 1);
 else ${"tipo_persona_costo_agg".$numca."_".$num_r} = "";
@@ -215,8 +222,8 @@ ${"data_inserimento_costo_agg".$numca."_".$num_r} = substr($dati_cap[$numca]['da
 ${"utente_inserimento_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['utente_inserimento'];
 } # fine if ($priv_mod_costi_agg != "n")
 } # fine for $numca
-if ($priv_mod_costi_agg != "n") ${"num_costi_aggiuntivi_".$num_r} = $dati_cap['num'];
-else ${"num_costi_aggiuntivi_".$num_r} = 0;
+if ($priv_mod_costi_agg != "n") ${"num_costi_aggiuntivi_".$num_r} = (string) $dati_cap['num'];
+else ${"num_costi_aggiuntivi_".$num_r} = "0";
 if (!empty($num_letti_agg['max'])) ${"n_letti_agg_".$num_r} = $num_letti_agg['max'];
 else ${"n_letti_agg_".$num_r} = null;
 if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i") {
@@ -268,13 +275,12 @@ ${"num_periodi_".$num_r} = $id_data_fine - $id_data_inizio + 1;
 } # fine if (numlin_query($dati_prenota) == 1)
 } # fine if  (!$id_data_inizio and $num2 == 1)
 if ($priv_vedi_tab_costi != "n" and $priv_mod_pagato != "n" and $priv_mod_pagato != "i") {
-if (defined('C_VERSIONE_ATTUALE') and C_VERSIONE_ATTUALE < 3.00) $pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento,utente_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
-else $pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,valuta,data_inserimento,utente_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
+$pagamenti = esegui_query("select * from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
 $num_pagamenti2 = numlin_query($pagamenti);
 for ($num3 = 0 ; $num3 < $num_pagamenti2 ; $num3++) {
 ${"data_paga".$num_pagamenti."_".$num_r} = substr(risul_query($pagamenti,$num3,'data_inserimento'),0,10);
 ${"utente_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'utente_inserimento');
-if (strcmp(risul_query($pagamenti,$num3,'metodo_pagamento'),"")) ${"metodo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'metodo_pagamento');
+if (strcmp((string) risul_query($pagamenti,$num3,'metodo_pagamento'),"")) ${"metodo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'saldo_prenota');
 if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99) {
 $valuta_paga = risul_query($pagamenti,$num3,'valuta');
@@ -284,17 +290,22 @@ ${"valuta_paga".$num_pagamenti."_".$num_r} = $valuta_paga[0];
 ${"tasso_cambio_paga".$num_pagamenti."_".$num_r} = $valuta_paga[1];
 ${"valore_valuta_paga".$num_pagamenti."_".$num_r} = converti_valuta(${"saldo_paga".$num_pagamenti."_".$num_r},$valuta_paga[1],$valuta_paga[2]);
 } # fine if ($valuta_paga)
+if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 3.04) {
+${"data_operazione_paga".$num_pagamenti."_".$num_r} = substr(risul_query($pagamenti,$num3,'data_transazione'),0,10);
+if (strcmp((string) risul_query($pagamenti,$num3,'id_pagamento'),"")) ${"id_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'id_pagamento');
+if (strcmp((string) risul_query($pagamenti,$num3,'note'),"")) ${"note_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'note');
+} # fine if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 3.04)
 } # fine if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99)
 $num_pagamenti++;
 } # fine for $num3
+chiudi_query($pagamenti);
 } # fine if ($priv_vedi_tab_costi != "n" and $priv_mod_pagato != "n" and $priv_mod_pagato != "i")
 } # fine if (numlin_query($anno_prec_esistente))
 } # fine for $num2
 } # fine if (${"id_anni_prec_".$num_r})
 } # fine if (!$id_data_inizio or ($priv_vedi_tab_costi != "n" and $priv_mod_pagato != "n" and $priv_mod_pagato != "i"))
 if ($priv_vedi_tab_costi != "n" and $priv_mod_pagato != "n" and $priv_mod_pagato != "i") {
-if (defined('C_VERSIONE_ATTUALE') and C_VERSIONE_ATTUALE < 3.00) $pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento,utente_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
-else $pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,valuta,data_inserimento,utente_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
+$pagamenti = esegui_query("select * from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
 $num_pagamenti2 = numlin_query($pagamenti);
 for ($num2 = 0 ; $num2 < $num_pagamenti2 ; $num2++) {
 ${"data_paga".$num_pagamenti."_".$num_r} = substr(risul_query($pagamenti,$num2,'data_inserimento'),0,10);
@@ -309,10 +320,16 @@ ${"valuta_paga".$num_pagamenti."_".$num_r} = $valuta_paga[0];
 ${"tasso_cambio_paga".$num_pagamenti."_".$num_r} = $valuta_paga[1];
 ${"valore_valuta_paga".$num_pagamenti."_".$num_r} = converti_valuta(${"saldo_paga".$num_pagamenti."_".$num_r},$valuta_paga[1],$valuta_paga[2]);
 } # fine if ($valuta_paga)
+if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 3.04) {
+${"data_operazione_paga".$num_pagamenti."_".$num_r} = substr(risul_query($pagamenti,$num2,'data_transazione'),0,10);
+if (strcmp((string) risul_query($pagamenti,$num2,'id_pagamento'),"")) ${"id_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num2,'id_pagamento');
+if (strcmp((string) risul_query($pagamenti,$num2,'note'),"")) ${"note_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num2,'note');
+} # fine if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 3.04)
 } # fine if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99)
 $num_pagamenti++;
 } # fine for $num2
-${"num_pagamenti_".$num_r} = $num_pagamenti;
+${"num_pagamenti_".$num_r} = (string) $num_pagamenti;
+chiudi_query($pagamenti);
 } # fine if ($priv_vedi_tab_costi != "n" and $priv_mod_pagato != "n" and $priv_mod_pagato != "i")
 } # fine if ($cont == "SI")
 } # fine if (numlin_query($dati_prenota) == 1)
