@@ -21,11 +21,15 @@
 ##################################################################################
 
 
-#if (function_exists('ini_set')) @ini_set('display_errors','Off');
-#error_reporting(E_ALL ^ E_NOTICE);
-#error_reporting(E_ALL);
+define('C_DEBUG_HD',"off");
+
 if (function_exists('version_compare') and version_compare(PHP_VERSION, '8.0.0', '>=')) error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED & ~E_WARNING);
 else error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
+/*if (C_DEBUG_HD == "on") {
+error_reporting(E_ALL);
+#if (function_exists('ini_set')) @ini_set('display_errors','Off');
+} # fine if (C_DEBUG_HD == "on")
+else error_reporting(E_ALL & ~E_STRICT & ~E_DEPRECATED);*/
 if (function_exists('mb_internal_encoding')) mb_internal_encoding('UTF-8');
 if (function_exists('date_default_timezone_set')) if (!ini_get('date.timezone')) date_default_timezone_set('UTC');
 
@@ -42,34 +46,23 @@ $var_pag[$n_var_pag++] = 'password_phpr';
 $var_pag[$n_var_pag++] = 'vers_hinc';
 $var_pag[$n_var_pag++] = 'test_cookie';
 for ($num1 = 0 ; $num1 < $n_var_pag; $num1++) {
-if (!isset(${$var_pag[$num1]})) {
-if (isset($_POST[$var_pag[$num1]])) ${$var_pag[$num1]} = $_POST[$var_pag[$num1]];
-elseif (isset($_GET[$var_pag[$num1]])) ${$var_pag[$num1]} = $_GET[$var_pag[$num1]];
-} # fine if (!isset(${$var_pag[$num1]}))
+if (isset($_REQUEST[$var_pag[$num1]]) and !isset(${$var_pag[$num1]})) ${$var_pag[$num1]} = $_REQUEST[$var_pag[$num1]];
 } # fine for $num1
 unset($var_pag);
 
+if (C_DEBUG_HD == "on") {
+if (@is_array($_REQUEST)) reset($_REQUEST);
+for ($num1 = 0 ; $num1 < count($_REQUEST); $num1++) {
+$var_REQUEST = key($_REQUEST);
+if (!isset($$var_REQUEST)) {
 # nel caso fosse settato register_globals = Off
-if (@is_array($_POST)) reset($_POST);
-for ($num1 = 0 ; $num1 < count($_POST); $num1++) {
-$var_POST = key($_POST);
-if (!isset($$var_POST)) {
-$$var_POST = $_POST[$var_POST];
-#echo "\$var_pag[".($n_var_pag++ - 6)."] = '".htmlspecialchars($var_POST)."';<br>";
-#error_log("PHP not registered variable in $pag: \$var_pag[".($n_var_pag - 6)."] = '$var_POST';");
-} # fine (!isset($$var_POST))
-next($_POST);
-} # fine for $num1
-if (@is_array($_GET)) reset($_GET);
-for ($num1 = 0 ; $num1 < count($_GET); $num1++) {
-$var_GET = key($_GET);
-if (!isset($$var_GET)) {
-$$var_GET = $_GET[$var_GET];
-#echo "\$var_pag[".($n_var_pag++ - 6)."] = '".htmlspecialchars($var_GET)."';<br>";
-#error_log("PHP not registered variable in $pag: \$var_pag[".($n_var_pag - 6)."] = '$var_GET';");
-} # fine if (!isset($$var_GET))
-next($_GET);
+#$$var_REQUEST = $_REQUEST[$var_REQUEST];
+error_log("PHP not registered variable in $pag: \$var_pag[".($n_var_pag++ - 6)."] = '$var_REQUEST';");
+echo "\$var_pag[".($n_var_pag - 7)."] = '".htmlspecialchars($var_REQUEST)."';<br>";
+} # fine (!isset($$var_REQUEST))
+next($_REQUEST);
 } # fine for $num1
+} # fine if (C_DEBUG_HD == "on")
 unset($n_var_pag);
 
 
@@ -82,8 +75,8 @@ $parole_sost = 0;
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',3.05);
-define('C_PHPR_VERSIONE_TXT',"3.0.5");
+define('C_PHPR_VERSIONE_NUM',3.06);
+define('C_PHPR_VERSIONE_TXT',"3.0.6");
 
 if (!isset($nome_utente_phpr)) $nome_utente_phpr = "";
 if (!isset($password_phpr)) $password_phpr = "";
@@ -304,9 +297,9 @@ return $stile_data;
 function formatta_data ($data,$stile_data="europa") {
 
 $data = (string) $data;
-$giorno = substr($data,8,2);
-$mese = substr($data,5,2);
-$anno = substr($data,0,4);
+$giorno = htmlspecialchars(substr($data,8,2));
+$mese = htmlspecialchars(substr($data,5,2));
+$anno = htmlspecialchars(substr($data,0,4));
 #$formato = "d-m-Y";
 #if ($stile_data == 'usa') $formato = "m-d-Y";
 #$data_formattata = date ($formato, mktime(0,0,0,$mese,$giorno,$anno));
@@ -314,7 +307,7 @@ switch ($stile_data) {
 case "usa": $data_formattata = $mese."-".$giorno."-".$anno; break;
 default: $data_formattata = $giorno."-".$mese."-".$anno;
 } # fine switch ($stile_data)
-$data_formattata .= substr($data,10);
+$data_formattata .= htmlspecialchars(substr($data,10));
 
 return $data_formattata;
 
@@ -570,6 +563,7 @@ $tabletransazioni = $PHPR_TAB_PRE."transazioni";
 $tabelle_lock = array($tableversioni,$tablesessioni,$tabletransazioni);
 $altre_tab_lock = array($tableutenti);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
+$nome_utente_phpr = trim($nome_utente_phpr);
 
 $sec_log_sbagliati = 5;
 $limite_login_sbagliati = date("Y-m-d H:i:s",(time() - $sec_log_sbagliati + (C_DIFF_ORE * 3600)));
@@ -616,6 +610,7 @@ else {
 
 $nome_utente_phpr = aggslashdb($nome_utente_phpr);
 $password_phpr = aggslashdb($password_phpr);
+if (trim($password_phpr) != $password_phpr) $password_phpr_orig = $password_phpr;
 $utente = esegui_query("select * from $tableutenti where nome_utente = '$nome_utente_phpr'");
 if (numlin_query($utente) == 1) {
 $nome_utente_login = risul_query($utente,0,'nome_utente');
@@ -623,11 +618,15 @@ $tipo_pass = risul_query($utente,0,'tipo_pass');
 $password = risul_query($utente,0,'password');
 if ($tipo_pass == "5") {
 if (C_VERSIONE_ATTUALE > 1.32) {
-$salt = risul_query($utente,0,'salt');
+$salt = (string) risul_query($utente,0,'salt');
 for ($num1 = 0 ; $num1 < 15 ; $num1++) $password_phpr = md5($password_phpr.substr($salt,0,(20 - $num1)));
 } # fine if (C_VERSIONE_ATTUALE > 1.32)
 else $password_phpr = md5($password_phpr);
 } # fine if ($tipo_pass == "5")
+if ($password != $password_phpr and isset($password_phpr_orig)) {
+$password_phpr = trim($password_phpr_orig);
+if ($tipo_pass == "5" and C_VERSIONE_ATTUALE > 1.32) for ($num1 = 0 ; $num1 < 15 ; $num1++) $password_phpr = md5($password_phpr.substr($salt,0,(20 - $num1)));
+} # fine if ($password != $password_phpr and isset($password_phpr_orig))
 
 # login effettuato con successo
 if ($password == $password_phpr and $tipo_pass != "n") {
@@ -885,7 +884,7 @@ echo "<form method=\"post\" action=\"aggiorna.php\"><div>
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/foot.php");
 else include("./includes/foot.php");
 } # fine else if ($id_utente == $id_utente_azione_ic) 
-unset($id_utente);
+$id_utente = "";
 } # fine if (@is_file(C_DATI_PATH."/dati_connessione.php") or...
 } # fine if (defined('C_VERSIONE_ATTUALE') and C_VERSIONE_ATTUALE < C_PHPR_VERSIONE_NUM and...
 
@@ -1125,16 +1124,13 @@ else unset($dates_options_list);
 
 if (substr($file,0,(strlen(C_DATI_PATH) + 15)) == C_DATI_PATH."/selperiodimenu" and floor($current_dates_menu / 2) != (($current_dates_menu - 1) / 2) and $mos_tut_dat != "SI" and $modifica_pers != "NO" and $partial_dates) {
 $lista_var = "";
-if (@is_array($_POST)) reset($_POST);
-for($num1 = 0 ; $num1 < count($_POST); $num1++) {
-if (key($_POST) != "mos_tut_dat" and substr(key($_POST),0,8) != "modifica") $lista_var .= "&amp;".urlencode(key($_POST))."=".urlencode(strip_magic_slashs($_POST[key($_POST)]));
-next($_POST);
-} # fine for $num1
-if (@is_array($_GET)) reset($_GET);
-for($num1 = 0 ; $num1 < count($_GET); $num1++) {
-if (key($_GET) != "mos_tut_dat" and substr(key($_GET),0,8) != "modifica") $lista_var .= "&amp;".urlencode(key($_GET))."=".urlencode(strip_magic_slashs($_GET[key($_GET)]));
-next($_GET);
+if (isset($_REQUEST) and is_array($_REQUEST)) {
+reset($_REQUEST);
+for($num1 = 0 ; $num1 < count($_REQUEST); $num1++) {
+if (key($_REQUEST) != "mos_tut_dat" and substr(key($_REQUEST),0,8) != "modifica") $lista_var .= "&amp;".urlencode(key($_REQUEST))."=".urlencode(strip_magic_slashs($_REQUEST[key($_REQUEST)]));
+next($_REQUEST);
 } # fine for $num1
+} # fine if (isset($_REQUEST) and is_array($_REQUEST))
 if ($lista_var) {
 global $pag;
 $lista_var = "?mos_tut_dat=SI".$lista_var;
@@ -1178,11 +1174,14 @@ if (function_exists('ob_flush')) ob_flush();
 
 
 
-function controlla_pag_origine ($origine) {
+function controlla_pag_origine (&$origine_passa) {
 
-$origine = trim((string) $origine);
+if (isset($origine_passa)) {
+$origine = trim((string) $origine_passa);
 if (substr($origine,0,2) == "./") $origine = substr($origine,2);
 if (strstr($origine,"http") or strstr($origine,"..") or strstr($origine,"/") or strstr($origine,"\\")) $origine = "inizio.php";
+} # fine if (isset($origine_passa))
+else $origine = "";
 
 return str_replace("\"","",str_replace(">","",str_replace("<","",$origine)));
 
@@ -1190,5 +1189,14 @@ return str_replace("\"","",str_replace(">","",str_replace("<","",$origine)));
 
 
 
+if (function_exists('mb_strcut')) {
+function par_taglia (&$str,$ini,$fine) { return mb_strcut($str,$ini,$fine); }
+} # fine if (function_exists('mb_strcut'))
+else {
+function par_taglia (&$str,$ini,$fine) { return substr($str,$ini,$fine); }
+} # fine else if (function_exists(''))
+
+
+
 
 ?>
