@@ -54,9 +54,9 @@ $appartamenti_consentiti[$id_appartamento] = "NO";
 
 foreach ($priv_ins_nuove_prenota_gr as $idut_gr => $val) {
 
-unset($condizioni_regole1_consentite);
-unset($appartamenti_consentiti_regola1);
-unset($appartamenti_consentiti_regola2);
+$condizioni_regole1_consentite = "";
+$appartamenti_consentiti_regola1 = array();
+$appartamenti_consentiti_regola2 = array();
 
 $attiva_regole1_consentite = $attiva_regole1_consentite_gr[$idut_gr];
 $regole1_consentite = $regole1_consentite_gr[$idut_gr];
@@ -90,7 +90,7 @@ $tutti_app_consentiti = "NO";
 $rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
 $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI") {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa])) {
 $tariffa = "tariffa".$numtariffa;
 $regola2 = esegui_query("select motivazione from $tableregole where tariffa_per_app = '$tariffa'");
 if (numlin_query($regola2) == 0) {
@@ -101,7 +101,7 @@ else {
 $appartamenti_regola2 = explode(",",risul_query($regola2,0,"motivazione"));
 for ($num1 = 0 ; $num1 < count($appartamenti_regola2) ; $num1++) $appartamenti_consentiti_regola2[$appartamenti_regola2[$num1]] = "SI";
 } # fine else if (numlin_query($regola2) == 0)
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa]))
 } # fine for $numtariffa
 if ($tutti_app_consentiti != "SI") {
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
@@ -113,7 +113,7 @@ if ($appartamenti_consentiti_regola2[$id_appartamento] != "SI") $appartamenti_co
 
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $id_appartamento = risul_query($appartamenti,$num1,'idappartamenti');
-if ($appartamenti_consentiti_regola1[$id_appartamento] != "NO" and $appartamenti_consentiti_regola2[$id_appartamento] != "NO") $appartamenti_consentiti[$id_appartamento] = "SI";
+if ((!isset($appartamenti_consentiti_regola1[$id_appartamento]) or $appartamenti_consentiti_regola1[$id_appartamento] != "NO") and (!isset($appartamenti_consentiti_regola2[$id_appartamento]) or $appartamenti_consentiti_regola2[$id_appartamento] != "NO")) $appartamenti_consentiti[$id_appartamento] = "SI";
 } # fine for $num1
 
 } # fine foreach ($priv_ins_nuove_prenota_gr as $idut_gr => $val)
