@@ -224,11 +224,15 @@ $dati_manda_email['spf'][$dominio] = $maschera_corr;
 } # fine else if (isset($dati_manda_email['spf'][$dominio]))
 } # fine if ($maschera_corr == "SI" and defined('C_MASCHERA_EMAIL') and
 
+if (function_exists('version_compare') and version_compare(PHP_VERSION,'8.0.0','>=')) $mailh_nl = "\r\n";
+else {
 switch (strtoupper(substr(PHP_OS,0,3))) {
 case "WIN": $mailh_nl = "\r\n"; break;
 case "MAC": $mailh_nl = "\r"; break;
 default: $mailh_nl = "\n"; break;
 } # fine switch (strtoupper(substr(PHP_OS,0,3)))
+} # fine else if (function_exists('version_compare') and version_compare(PHP_VERSION, '8.0.0', '>='))
+$mailb_nl = $mailh_nl;
 if ($nome_mittente and !$reply_to) $headers = "From: \"".str_replace('"','',$nome_mittente)."\" <$mittente_email>$mailh_nl";
 else $headers = "From: <$mittente_email>$mailh_nl";
 if ($reply_to) {
@@ -249,21 +253,21 @@ $headers .= " boundary=\"$boundary\"$mailh_nl";
 #$headers .= "X-Mailer: PHP$mailh_nl";
 #$headers .= "X-Priority: 3$mailh_nl";
 #$headers .= "Return-Path: $mittente_email$mailh_nl";
-$testo_email = "This is a multi-part message in MIME format.\n--$boundary\nContent-type: $cont_type; charset=utf-8\nContent-Transfer-Encoding: base64\n\n$testo_email";
+$testo_email = "This is a multi-part message in MIME format.$mailb_nl--$boundary$mailb_nl"."Content-type: $cont_type; charset=utf-8$mailb_nl"."Content-Transfer-Encoding: base64$mailb_nl$mailb_nl$testo_email";
 for ($num1 = 1 ; $num1 <= $dati_allegato['num'] ; $num1++) {
 if ($allega[$num1] == "SI") {
-if (substr($testo_email,-1) == "\n") $testo_email .= "\n--$boundary\n";
-else $testo_email .= "--$boundary\n";
-$testo_email .= "Content-Type: ".$dati_allegato[$num1]['tipo'].";\n";
-$testo_email .= " name=\"".$dati_allegato[$num1]['nome']."\"\n";
-$testo_email .= "Content-Transfer-Encoding: base64\n";
-$testo_email .= "Content-Disposition: attachment;\n";
-$testo_email .= " filename=\"".$dati_allegato[$num1]['nome']."\"\n\n";
+if (substr($testo_email,-1) == $mailb_nl or substr($testo_email,-2) == $mailb_nl) $testo_email .= "$mailb_nl--$boundary$mailb_nl";
+else $testo_email .= "--$boundary$mailb_nl";
+$testo_email .= "Content-Type: ".$dati_allegato[$num1]['tipo'].";$mailb_nl";
+$testo_email .= " name=\"".$dati_allegato[$num1]['nome']."\"$mailb_nl";
+$testo_email .= "Content-Transfer-Encoding: base64$mailb_nl";
+$testo_email .= "Content-Disposition: attachment;$mailb_nl";
+$testo_email .= " filename=\"".$dati_allegato[$num1]['nome']."\"$mailb_nl$mailb_nl";
 $testo_email .= $dati_allegato[$num1]['valo'];
 } # fine if ($allega[$num1] == "SI")
 } # fine for $num1
-if (substr($testo_email,-1) == "\n") $testo_email .= "--$boundary--";
-else $testo_email .= "\n--$boundary--";
+if (substr($testo_email,-1) == $mailb_nl or substr($testo_email,-2) == $mailb_nl) $testo_email .= "--$boundary--";
+else $testo_email .= "$mailb_nl--$boundary--";
 } # fine if ($allegato_presente)
 else {
 if ($cont_type != "text/plain") $headers .= "MIME-Version: 1.0$mailh_nl";
