@@ -74,7 +74,7 @@ if (!$risul[-1]) {
 $risul = $risul[-1];
 if ($silenzio != "totale") {
 global $PHPR_TAB_PRE;
-if (!$silenzio) echo "<br>ERROR IN: ".str_replace(" ".$PHPR_TAB_PRE," ",$query)." <br>".mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli)."<br>";
+if (!$silenzio) echo "<br>ERROR IN: ".htmlspecialchars(str_replace(" ".$PHPR_TAB_PRE," ",$query))." <br>".htmlspecialchars(mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli))."<br>";
 error_log("IN ".$_SERVER['PHP_SELF']." MYSQL ERROR: ".substr(str_replace(" ".$PHPR_TAB_PRE," ",$query),0,25)."... - ".mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli));
 } # fine if ($silenzio != "totale")
 } # fine if (!$risul[-1])
@@ -106,7 +106,7 @@ if (!$risul[-1]) {
 $risul = $risul[-1];
 if ($silenzio != "totale") {
 global $PHPR_TAB_PRE;
-if (!$silenzio) echo "<br>ERROR IN: ".str_replace(" ".$PHPR_TAB_PRE," ",$query)." <br>".mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli)."<br>";
+if (!$silenzio) echo "<br>ERROR IN: ".htmlspecialchars(str_replace(" ".$PHPR_TAB_PRE," ",$query))." <br>".htmlspecialchars(mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli))."<br>";
 error_log("IN ".$_SERVER['PHP_SELF']." MYSQL ERROR: ".substr(str_replace(" ".$PHPR_TAB_PRE," ",$query),0,25)."... - ".mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli));
 } # fine if ($silenzio != "totale")
 } # fine if (!$risul[-1])
@@ -239,7 +239,7 @@ $lista_tabelle = substr($lista_tabelle,0,-1);
 global $link_mysqli;
 $risul = mysqli_query($link_mysqli,"lock tables $lista_tabelle");
 if (!$risul) {
-echo "<br>ERROR IN: lock tables $lista_tabelle<br>".mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli)."<br>";
+echo "<br>ERROR IN: lock tables ".htmlspecialchars($lista_tabelle)."<br>".htmlspecialchars(mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli))."<br>";
 error_log("IN ".$_SERVER['PHP_SELF']." MYSQL ERROR: lock tables $lista_tabelle - ".mysqli_errno($link_mysqli).": ".mysqli_error($link_mysqli));
 } # fine if (!$risul)
 
@@ -267,4 +267,4 @@ mysqli_query($link_mysqli,"alter table $tabella add index $nome ($colonne)");
 
 
 
-?>
\ No newline at end of file
+?>
