@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -74,6 +74,7 @@ if ($mostra_quadro_disp == "pers") {
 asort ($dati_app['maxocc']);
 reset ($dati_app['maxocc']);
 $ultime_persone_casa = "vuoto";
+if (empty($app_ric_raggr[$num_raggr])) $app_ric_raggr[$num_raggr] = "";
 foreach ($dati_app['maxocc'] as $key => $val) {
 $persone_casa = $val;
 if ($persone_casa != $ultime_persone_casa) {
@@ -85,10 +86,11 @@ else $nome_raggr[$num_raggr] = $ultime_persone_casa."&nbsp;".$fr_persone;
 } # fine if ($ultime_persone_casa)
 else $nome_raggr[$num_raggr] = "?&nbsp;$fr_persone";
 $num_raggr++;
+if (empty($app_ric_raggr[$num_raggr])) $app_ric_raggr[$num_raggr] = "";
 } # fine if ($app_ric_raggr[$num_raggr])
 $ultime_persone_casa = $persone_casa;
 } # fine if ($persone_casa != $ultimepersone_casa)
-if ($app_consentito[$key] == "SI") $app_ric_raggr[$num_raggr] .= "$key,";
+if (isset($app_consentito[$key]) and $app_consentito[$key] == "SI") $app_ric_raggr[$num_raggr] .= "$key,";
 } # fine foreach ($dati_app['maxocc'] as $key => $val)
 if ($app_ric_raggr[$num_raggr]) {
 $app_ric_raggr[$num_raggr] = substr($app_ric_raggr[$num_raggr],0,-1);
@@ -131,7 +133,7 @@ lista_prenota_periodo($id_periodo,$id_periodo,$dati_app,$prenota_in_app_sett,$pr
 for ($num3 = 0 ; $num3 < $num_lista_pren_per ; $num3++) {
 if (str_replace(",".$app_orig_prenota_id[$lista_prenota_periodo[$num3]].",","",$app_ric_colonna) != $app_ric_colonna) $num_app_liberi--;
 } # fine for $num3
-if ($napp_ric_raggr[$num1]) $num_app_liberi = floor($num_app_liberi / $napp_ric_raggr[$num1]);
+if (!empty($napp_ric_raggr[$num1])) $num_app_liberi = floor($num_app_liberi / $napp_ric_raggr[$num1]);
 if ($mostra_quadro_disp == "reg2" and $dati_tariffe and !empty($dati_tariffe[$tipotariffa[$num1]]['chiusa'][$id_periodo])) $num_app_liberi = 0;
 if ($num_app_liberi > 0) $color = $c_libero_tab_disp;
 else $color = $c_occupato_tab_disp;
