@@ -95,7 +95,7 @@ else $risultato = $risul;
 
 if (!$risul and $silenzio != "totale") {
 global $PHPR_TAB_PRE;
-if (!$silenzio) echo "<br>ERROR in: ".str_replace(" ".$PHPR_TAB_PRE," ",$query)."<br>";
+if (!$silenzio) echo "<br>ERROR in: ".htmlspecialchars(str_replace(" ".$PHPR_TAB_PRE," ",$query))."<br>";
 error_log("IN ".$_SERVER['PHP_SELF']." SQLITE ERROR: ".substr(str_replace(" ".$PHPR_TAB_PRE," ",$query),0,25)."...");
 } # fine (!$risul and $silenzio != "totale")
 
@@ -241,4 +241,4 @@ $numconnessione->exec("create index $nome on $tabella ($colonne)");
 
 
 
-?>
\ No newline at end of file
+?>
