@@ -268,7 +268,7 @@ $numero = 0;
 $dist_dopo = 0;
 $dist_prima = 0;
 $testo_vett = preg_split("/$parola"."[^0-9a-z]/i",$testo);
-if ($testo_vett[1]) {
+if (!empty($testo_vett[1])) {
 $testo_vett[1] = " ".$testo_vett[1];
 # Numero dopo la parola cercata
 $num = preg_split("/[^0-9a-z][0-9]{1,2}[^0-9a-z]/i",substr($testo_vett[1],0,16));
@@ -286,7 +286,7 @@ $numero = substr($testo_vett[0],(($dist_prima * -1) - 1),1);
 if (preg_match("/[0-9]/",substr($testo_vett[0],(($dist_prima * -1) - 2),1))) $numero = substr($testo_vett[0],(($dist_prima * -1) - 2),1).$numero;
 } # fine if (!$numero or $dist_prima < $dist_dopo)
 } # fine if (count($num) > 1)
-} # fine if ($testo_vett[1])
+} # fine if (!empty($testo_vett[1]))
 
 return $numero;
 
