@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -79,8 +79,8 @@ function upload_hd_img ($filename,$ord="") {
 if (defined('C_CARTELLA_CREA_MODELLI') and C_CARTELLA_CREA_MODELLI != "") {
 global ${"file_hd_img_upload$ord"};
 if (!${"file_hd_img_upload$ord"}) {
-if ($HTTP_POST_FILES["file_hd_img_upload$ord"]['tmp_name']) ${"file_hd_img_upload$ord"} = $HTTP_POST_FILES["file_hd_img_upload$ord"]['tmp_name'];
-else if ($_FILES["file_hd_img_upload$ord"]['tmp_name']) ${"file_hd_img_upload$ord"} = $_FILES["file_hd_img_upload$ord"]['tmp_name'];
+if (!empty($HTTP_POST_FILES["file_hd_img_upload$ord"]['tmp_name'])) ${"file_hd_img_upload$ord"} = $HTTP_POST_FILES["file_hd_img_upload$ord"]['tmp_name'];
+else if (!empty($_FILES["file_hd_img_upload$ord"]['tmp_name'])) ${"file_hd_img_upload$ord"} = $_FILES["file_hd_img_upload$ord"]['tmp_name'];
 } # fine if (!${"file_hd_img_upload$ord"})
 if (${"file_hd_img_upload$ord"}) {
 
