@@ -29,19 +29,19 @@ include($file_interconnessioni);
 if (@is_array($ic_present)) {
 flush();
 if (function_exists('ob_flush')) ob_flush();
-if ($closed_on_arr_dep != "SI") $closed_on_arr_dep = "NO";
+if (!isset($closed_on_arr_dep) or $closed_on_arr_dep != "SI") $closed_on_arr_dep = "NO";
 
 $interconn_dir = opendir("./includes/interconnect/");
 while ($mod_ext = readdir($interconn_dir)) {
 if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) {
 include("./includes/interconnect/$mod_ext/name.php");
-if ($ic_present[$interconnection_name] == "SI") {
+if (isset($ic_present[$interconnection_name]) and $ic_present[$interconnection_name] == "SI") {
 $funz_update_availability = "update_availability_".$interconnection_func_name;
 $funz_update_rates = "update_rates_".$interconnection_func_name;
 if (!function_exists($funz_update_availability)) include("./includes/interconnect/$mod_ext/functions.php");
 if ($aggiorna_disp) $funz_update_availability($file_interconnessioni,$anno,$PHPR_TAB_PRE,$lock);
 if ($aggiorna_tar) $funz_update_rates($file_interconnessioni,$anno,$PHPR_TAB_PRE,$lock,"NO",$closed_on_arr_dep);
-} # fine if ($ic_present[$interconnection_name] == "SI")
+} # fine if (isset($ic_present[$interconnection_name]) and $ic_present[$interconnection_name] == "SI")
 } # fine if ($modello_ext != "." and $modello_ext != ".." and...
 } # fine while ($mod_ext = readdir($interconn_dir))
 closedir($interconn_dir);
