@@ -31,7 +31,7 @@ case "della tariffa arrotondato a":  		$messaggio = "of the rate rounded to"; br
 case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "consider this percentage cost as an extra bed(s)"; break;
 case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Proceed inserting the new extra cost"; break;
 case "Caparra":  				$messaggio = "Deposit"; break;
-case "La caparra normale per la":  		$messaggio = "The normal deposit for"; break;
+case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
 case "arrotondata a":  				$messaggio = "rounded to"; break;
 case "Inserisci o modifica la caparra":  	$messaggio = "Insert or modify the deposit"; break;
 case "Vedi i prezzi già inseriti":  		$messaggio = "View the prices already inserted"; break;
@@ -231,7 +231,7 @@ case "La caparra è errata":  			$messaggio = "The deposit is wrong"; break;
 case "è":  					$messaggio = "is"; break;
 case "il":  					$messaggio = "the"; break;
 case "Commissioni":  				$messaggio = "Commissions"; break;
-case "Le commissioni normali sulla":  		$messaggio = "The normal commissions on"; break;
+case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
 case "sono":  					$messaggio = "are"; break;
 case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
 case "Tasse":  					$messaggio = "Taxes"; break;
