@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Ospiti":  			$messaggio = "Modify Guests"; break;
 case "Modifica gli ospiti della prenotazione":	$messaggio = "Modify guests of reservation"; break;
 case "Cliente titolare":  			$messaggio = "Titular client"; break;
 case "Ospite della prenotazione":  		$messaggio = "Guest of reservation"; break;
@@ -47,6 +48,9 @@ case "Modifica gli ospiti delle prenotazioni":	$messaggio = "Modify guests of re
 case "della prenotazione":  			$messaggio = "of reservation"; break;
 case "Gli ospiti delle prenotazioni":  		$messaggio = "The guests of reservations"; break;
 case "ln.":  					$messaggio = "ln."; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC/codice":  				$messaggio = "certified email"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
