@@ -277,12 +277,9 @@ case "Data operazione":  			$messaggio = "Transaction date"; break;
 case "Data":  					$messaggio = "Date"; break;
 case "Note":  					$messaggio = "Notes"; break;
 case "Informazioni extra":  			$messaggio = "Extra info"; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
-case "":  		$messaggio = ""; break;
+case "Inserisci una prenotazione uguale":  	$messaggio = "Insert a reservation like this"; break;
+case "Inserisci prenotazioni uguali":  		$messaggio = "Insert reservations like these"; break;
+case "Cambia il cliente anche nei pagamenti effettuati":	$messaggio = "Change client also in payments already made"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
