@@ -472,9 +472,22 @@ case "Questo è il record SPF attuale del dominio":	$messaggio = "This is the cu
 case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "this TXT record must be modified in the management of DNS of the domain"; break;
 case "sostituendolo con un testo come questo":	$messaggio = "replacing it with a text like this"; break;
 case "Dopo la modifica potrebbero volerci alcune ore affinchè l'aggiornamento sia attivo":	$messaggio = "After the change it may take a few hours for the update to take effect"; break;
+case "Formato di nomi e cognomi":  		$messaggio = "Format of names and surnames"; break;
+case "non modificare il formato inserito":  	$messaggio = "don't modify inserted format"; break;
+case "prima lettera maiuscola, altre lettere minuscole":	$messaggio = "first letter uppercase, other letters lowercase"; break;
+case "prima lettera maiuscola, non modificare altre lettere":	$messaggio = "first letter uppercase, do not change other letters"; break;
+case "tutte lettere maiuscole":  		$messaggio = "all letters uppercase"; break;
+case "tutte lettere minuscole":  		$messaggio = "all letters lowercase"; break;
+case "Il formato di inserimento dei nomi e cognimi è stato cambiato":	$messaggio = "The format for inserting names and surnames has been changed"; break;
+case "Per il proprio indirizzo email si sta usando un provider pubblico":	$messaggio = "For your email address you are using a public provider"; break;
+case "si consiglia quindi di":  		$messaggio = "it is therefore advisable to"; break;
+case "configurare il loro server remoto smtp":	$messaggio = "configure their remote smtp server"; break;
+case "per inviare email":  			$messaggio = "to avoid that emails sent"; break;
+case "da hoteldruid":  				$messaggio = "from hoteldruid"; break;
+case "senza che vengano considerate come spam":	$messaggio = "are considered as spam"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
