@@ -1,6 +1,6 @@
 <?php
 
-if (substr($messaggio,0,4) != "var_") {
+if (substr((string) $messaggio,0,4) != "var_") {
 switch ($messaggio) {
 
 # translate YES and NO in upper case
@@ -315,10 +315,10 @@ case "Il codice":  				$messaggio = "El código"; break;
 case "aggiunge":  				$messaggio = "añade"; break;
 case "rimuove":  				$messaggio = "elimina"; break;
 case "il":  					$messaggio = "el"; break;
-case "Codice promozionale":  			$messaggio = "Código promicional"; break;
+case "Codice promozionale":  			$messaggio = "Código promocional"; break;
 case "Solo quelli selezionati per essere mostrati":	$messaggio = "Solo los seleccionados para enseñar"; break;
-case "Codice promozionale applicato":  		$messaggio = "Código promicional aplicado"; break;
-case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "algunos costes añadidos con código promicional"; break;
+case "Codice promozionale applicato":  		$messaggio = "Código promocional aplicado"; break;
+case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "algunos costes añadidos con código promocional"; break;
 case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "no están asociados a tarifas, algunas de sus características podrían ser modificadas si no son compatibles"; break;
 case "Mostrare le date passate?":  		$messaggio = "Enseñar las fechas pasadas?"; break;
 case "titolo html":  				$messaggio = "Título html"; break;
@@ -331,6 +331,10 @@ case "Valuta della caparra":  			$messaggio = "Divisa de la fianza"; break;
 case "Seconda email":  				$messaggio = "Segunda email"; break;
 case "PEC o codice destinatario":  		$messaggio = "Email certificada"; break;
 case "non deve contenere \"php\" e deve terminare con \".js\"":	$messaggio = "no debe contener \"php\" y debe terminar con \".js\""; break;
+case "notte":  					$messaggio = "noche"; break;
+case "notti":  					$messaggio = "noches"; break;
+case "cambia date":  				$messaggio = "cambiar fechas"; break;
+case "Per questa tariffa si deve inserire un minimo di":	$messaggio = "Para esta tarifa hay que insertar por lo menos"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -338,7 +342,7 @@ case "":  		$messaggio = ""; break;
 case "mdl_disponibilita":  			$messaggio = "mdl_disponibilidad"; break;
 
 } # fine switch ($messaggio)
-} # fine if (substr($messaggio,0,4) != "var_")
+} # fine if (substr((string) $messaggio,0,4) != "var_")
 
 
 else {
@@ -614,12 +618,16 @@ case "var_fr_con_posizioni_vicine":  		$messaggio = "var_fr_con_posiciones_cerca
 case "var_fr_Codice_promozionale":  		$messaggio = "var_fr_Codigo_promocional"; break;
 case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_fr_Codigo_promocional_aplicado"; break;
 case "var_fr_Si_deve_inserire_almeno_una_persona_che_possa_ecc":	$messaggio = "var_fr_Hay_que_incluir_al_menos_una_persona_que_pueda_etc"; break;
+case "var_fr_notte":  				$messaggio = "var_fr_noche"; break;
+case "var_fr_notti":  				$messaggio = "var_fr_noches"; break;
+case "var_fr_cambia_date":  			$messaggio = "var_fr_cambiar_fechas"; break;
+case "var_fr_Per_questa_tariffa_si_deve_inserire_un_minimo_di":	$messaggio = "var_fr_Para_esta_tarifa_hay_que_insertar_por_lo_menos"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
 
 } # fine switch ($messaggio)
-} # fine else if (substr($messaggio,0,4) != "var_")
+} # fine else if (substr((string) $messaggio,0,4) != "var_")
 
 
 
-?>
\ No newline at end of file
+?>
