@@ -32,7 +32,7 @@ case "della tariffa arrotondato a":  		$messaggio = "de la tarifa redondeado a";
 case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "considera el coste percentual como cama(s) extra(s)"; break;
 case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Seguir insertando el nuevo coste añadido"; break;
 case "Caparra":  				$messaggio = "Fianza"; break;
-case "La caparra normale per la":  		$messaggio = "La fianza normal para la"; break;
+case "La caparra normale per":  		$messaggio = "La fianza normal para"; break;
 case "arrotondata a":  				$messaggio = "redondeada a"; break;
 case "Inserisci o modifica la caparra":  	$messaggio = "Insertar o modificar la fianza"; break;
 case "Vedi i prezzi già inseriti":  		$messaggio = "Mirar los precios ya insertados"; break;
@@ -232,7 +232,7 @@ case "La caparra è errata":  			$messaggio = "La fianza está equivocada"; brea
 case "è":  					$messaggio = "es"; break;
 case "il":  					$messaggio = "el"; break;
 case "Commissioni":  				$messaggio = "Comisiones"; break;
-case "Le commissioni normali sulla":  		$messaggio = "Las comisiones normales sobre la"; break;
+case "Le commissioni normali su":  		$messaggio = "Las comisiones normales sobre"; break;
 case "sono":  					$messaggio = "son"; break;
 case "Tasse":  					$messaggio = "Tasas"; break;
 case "Tasse applicate su":  			$messaggio = "Tasas aplicadas sobre"; break;
