@@ -84,6 +84,7 @@ case "Incrementa il numero progressivo ad ogni sua apparizione":	$messaggio = "I
 case "Ogni documento avrà un unico numero progressivo":	$messaggio = "Cada documento tendrá un único número progresivo"; break;
 case "Il numero progressivo verrà incrementato ogni volta che compare nel documento":	$messaggio = "El número progresivo será incrementado daca vez que aparezca en el documento"; break;
 case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extensión para ver y descargar el documento"; break;
+case "Nome con cui vedere e scaricare il documento":	$messaggio = "Nombre para ver y descargar el documento"; break;
 case "predefinita":  				$messaggio = "predefinida"; break;
 case "personalizzata":  			$messaggio = "personalizada"; break;
 case "Estensione cambiata":  			$messaggio = "Extensión cambiada"; break;
@@ -120,6 +121,24 @@ case "Formati predefiniti del documento cambiati":	$messaggio = "Formatos predef
 case "i documenti esistenti non verranno mai sovrascritti, ogni volta che si chiama la API verrà salvato un nuovo documento":	$messaggio = "los documentos existentes nunca serán sobrescritos, cada vez que se llama la API se guardará un nuevo documento"; break;
 case "Tutti i pagamenti nella cassa":  		$messaggio = "Todos los pagos en la caja"; break;
 case "nome_cassa":  				$messaggio = "nombre_caja"; break;
+case "nome del documento o del file salvato":  	$messaggio = "nombre del documento o del archivo salvado"; break;
+case "variabile":  				$messaggio = "variable"; break;
+case "Verrà usato il nome del documento (o il nome del file salvato) come nome per il file scaricato":	$messaggio = "El nombre del documento (o el nombre del archivo salvado) se usará como nombre para el archivo descargado"; break;
+case "Verrà usato il valore della variabile":  	$messaggio = "Se utilizará el valor de la variable"; break;
+case "come nome del file scaricato":  		$messaggio = "como nombre para el archivo descargado"; break;
+case "escludendo l'estensione":  		$messaggio = "excluyendo la extensión"; break;
+case "Se la variabile non è definita verrà usato il nome del documento":	$messaggio = "Si la variable no está definida entonces se usará el nombre del documento"; break;
+case "È comunque possibile mostrare <em>una sola ripetizione per ogni cliente</em> usando le variabili":	$messaggio = "Sin embargo es posible mostrar <em>una sola repetición por cliente</em> usando las variables"; break;
+case "in una condizione come questa":  		$messaggio = "en una condición como esta"; break;
+case "aggiungi ora questa condizione al documento":	$messaggio = "añadir ahora esta condición al documento"; break;
+case "Così i dati delle ripetizioni precedenti possono essere memorizzati in uno o più array della variabile":	$messaggio = "Así los datos de las repeticiones anteriores pueden ser almacenados en uno o más arrays de la variable"; break;
+case "È stato trovato un allegato uguale":  	$messaggio = "Se ha encontrado un archivo adjunto idéntico"; break;
+case "riutilizzare l'allegato esistente o renderlo predefinito per evitare di ingombreare il database":	$messaggio = "reutilicar el archivo adjunto existente o convertirlo a predefinido para evitar saturar la base de datos"; break;
+case "Unisci più condizioni con":  		$messaggio = "Combinar múltiples condiciones con"; break;
+case "sempre da sinistra a destra":  		$messaggio = "siempre de izquierda a derecha"; break;
+case "Indirizzi IP":  				$messaggio = "Direcciones IP"; break;
+case "lista separata da virgole, qualsiasi IP se vuota":	$messaggio = "lista separada por comas, cualquier IP si está vacía"; break;
+case "Gli indirizzi IP da cui è permesso accedere alla API del documento sono stati cambiati":	$messaggio = "Las direcciones IP desde las que se permite el acceso a la API del documento han sido cambiadas"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
