@@ -277,6 +277,9 @@ case "Data operazione":  			$messaggio = "Fecha de la operación"; break;
 case "Data":  					$messaggio = "Fecha"; break;
 case "Note":  					$messaggio = "Notas"; break;
 case "Informazioni extra":  			$messaggio = "Informaciones extra"; break;
+case "Inserisci una prenotazione uguale":  	$messaggio = "Insertar una reserva igual"; break;
+case "Inserisci prenotazioni uguali":  		$messaggio = "Insertar reservas iguales"; break;
+case "Cambia il cliente anche nei pagamenti effettuati":	$messaggio = "Cambiar el cliente también en los pagos realizados"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
