@@ -472,9 +472,22 @@ case "Questo è il record SPF attuale del dominio":	$messaggio = "Este es el rec
 case "questo record TXT va modificato nella gestione del DNS del dominio":	$messaggio = "este record TXT debe ser modificado en la gestión del DNS del dominio"; break;
 case "sostituendolo con un testo come questo":	$messaggio = "reemplazándolo con un texto como este"; break;
 case "Dopo la modifica potrebbero volerci alcune ore affinchè l'aggiornamento sia attivo":	$messaggio = "Después del cambio, la actualización puede tardar algunas horas en tener efecto."; break;
+case "Formato di nomi e cognomi":  		$messaggio = "Formato de nombres y apellidos"; break;
+case "non modificare il formato inserito":  	$messaggio = "no modificar el formato ingresado"; break;
+case "prima lettera maiuscola, altre lettere minuscole":	$messaggio = "primera letra mayúscula, otras letras minúsculas"; break;
+case "prima lettera maiuscola, non modificare altre lettere":	$messaggio = "primera letra en mayúscula, no cambiar otras letras"; break;
+case "tutte lettere maiuscole":  		$messaggio = "todas letras mayúsculas"; break;
+case "tutte lettere minuscole":  		$messaggio = "todas letras minúsculas"; break;
+case "Il formato di inserimento dei nomi e cognimi è stato cambiato":	$messaggio = "El formato de ingreso de nombres y apellidos ha sido cambiado"; break;
+case "Per il proprio indirizzo email si sta usando un provider pubblico":	$messaggio = "Para la dirección de correo electrónico se está utilizando un proveedor público"; break;
+case "si consiglia quindi di":  		$messaggio = "por lo tanto se recomienda"; break;
+case "configurare il loro server remoto smtp":	$messaggio = "configurar su servidor smtp remoto"; break;
+case "per inviare email":  			$messaggio = "para enviar correos electrónicos"; break;
+case "da hoteldruid":  				$messaggio = "desde hoteldruid"; break;
+case "senza che vengano considerate come spam":	$messaggio = "sin que sean considerados spam"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
 } # fine switch ($messaggio)
 
-?>
\ No newline at end of file
+?>
