@@ -36,6 +36,7 @@ $trad_var['email2'] = 'email2';
 $trad_var['email_certificata'] = 'email_certificado';
 $trad_var['codice_fiscale'] = 'num_identificacion_fiscal';
 $trad_var['partita_iva'] = 'certificado_identificacion_fiscal';
+$trad_var['numero_cliente'] = 'numero_cliente';
 $trad_var['num_persone'] = 'num_personas';
 $trad_var['n_letti_agg'] = 'num_camas_extras';
 $trad_var['num_persone_tot'] = 'num_personas_tot';
@@ -70,6 +71,7 @@ $trad_var['promemoria_uscita'] = 'recordatorio_salida';
 $trad_var['origine_prenotazione'] = 'origen_reserva';
 $trad_var['unita_occupata'] = 'unidad_ocupada';
 $trad_var['unita_assegnabili'] = 'lista_unidades';
+$trad_var['conferma'] = 'confirmacion';
 $trad_var['pagato'] = 'pagado';
 $trad_var['pagato_p'] = 'pagado_p';
 $trad_var['resto_da_pagare'] = 'resto_a_pagar';
@@ -129,8 +131,12 @@ $trad_var['tasso_cambio_pagamento'] = 'tipo_cambio_pago';
 $trad_var['data_pagamento'] = 'fecha_pago';
 $trad_var['utente_pagamento'] = 'usuario_pago';
 $trad_var['metodo_pagamento'] = 'metodo_pago';
+$trad_var['id_pagamento'] = 'id_pago';
+$trad_var['note_pagamento'] = 'notas_pago';
+$trad_var['data_operazione_pagamento'] = 'fecha_operacion_pago';
 $trad_var['tutti_i_pagamenti'] = 'todos_los_pagos';
 $trad_var['tutti_i_pagamenti_p'] = 'todos_los_pagos_p';
+$trad_var['ultimo_pagamento'] = 'ultimo_pago';
 $trad_var['valore_ultimo_pagamento'] = 'valor_ultimo_pago';
 $trad_var['valore_ultimo_pagamento_p'] = 'valor_ultimo_pago_p';
 $trad_var['data_ultimo_pagamento'] = 'fecha_ultimo_pago';
@@ -140,6 +146,7 @@ $trad_var['num_pagamenti'] = 'num_pagos';
 $trad_var['numero_prenotazione'] = 'numero_reserva';
 $trad_var['numero_ripetizione_prenotazioni'] = 'numero_repeticion_reservas';
 $trad_var['codice_prenotazione'] = 'codigo_reserva';
+$trad_var['ultima_prenotazione_per_cliente'] = 'ultima_reserva_del_cliente';
 $trad_var['data_inserimento_prenotazione'] = 'fecha_insercion_reserva';
 $trad_var['utente_inserimento_prenotazione'] = 'usuario_insercion_reserva';
 $trad_var['numero_progressivo_documento'] = 'numero_progresivo_documento';
@@ -178,6 +185,7 @@ $trad_var['codice3_regione_documento'] = 'codigo3_region_documento';
 $trad_var['codice3_nazione_documento'] = 'codigo3_nacion_documento';
 $trad_var['num_ospiti_tot'] = 'num_huespedes_tot';
 $trad_var['numero_ospite'] = 'numero_huesped';
+$trad_var['numero_cliente_ospite'] = 'numero_cliente_huesped';
 $trad_var['cognome_ospite'] = 'apellido_huesped';
 $trad_var['nome_ospite'] = 'nombre_huesped';
 $trad_var['soprannome_ospite'] = 'apodo_huesped';
@@ -310,6 +318,9 @@ $trad_var['nome_documento_salvato'] = 'nombre_documento_salvado';
 $trad_var['numero_progressivo_documento_salvato'] = 'numero_progresivo_documento_salvado';
 $trad_var['data_creazione_documento_salvato'] = 'fecha_creacion_documento_salvado';
 $trad_var['nome_file_documento_salvato'] = 'nombre_archivo_documento_salvado';
+$trad_var['nome_download_documento_salvato'] = 'nombre_descarga_documento_salvado';
+$trad_var['nome_documento_scaricato'] = 'nombre_documento_descargado';
+$trad_var['allegato'] = 'archivo_adjunto';
 
 
 ?>
\ No newline at end of file
