@@ -24,6 +24,7 @@
 
 global $debug,$sec_limite_libsett;
 $debug = "off";
+#if (defined('C_DEBUG_HD') and C_DEBUG_HD == "on") $debug = "on";
 $sec_limite_libsett = 0;
 #apd_set_pprof_trace();
 #if (function_exists('ini_set')) @ini_set('xdebug.max_nesting_level',1000000);
@@ -46,8 +47,9 @@ $limiti_var['tutti_fissi'] = risul_query($prenota_tutte_fisse,0,'valpersonalizza
 if ($limiti_var['tutti_fissi'] != "SI") {
 if (defined("C_SEC_LIMITE_LIBERA_APP") and C_SEC_LIMITE_LIBERA_APP != "") $sec_limite_libsett = C_SEC_LIMITE_LIBERA_APP;
 else $sec_limite_libsett = $limiti_var['tutti_fissi'];
-$limiti_var['t_limite'] = (time() + $sec_limite_libsett);
 } # fine if ($limiti_var['tutti_fissi'] != "SI")
+else $sec_limite_libsett = 2;
+$limiti_var['t_limite'] = (time() + $sec_limite_libsett);
 } # fine if (!isset($limiti_var['tutti_fissi']))
 if (!isset($limiti_var['lim_prenota_temp'])) {
 $minuti_durata_insprenota = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'minuti_durata_insprenota' and idutente = '1'");
@@ -56,7 +58,7 @@ $limiti_var['lim_prenota_temp'] = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 360
 } # fine if (!isset($limiti_var['lim_prenota_temp']))
 
 # metto i dati della tabella appartamenti in $dati_app
-if (!$dati_app) {
+if (empty($dati_app)) {
 $idapp = esegui_query("select idappartamenti,maxoccupanti,app_vicini from $tableappartamenti order by priorita");
 $numappartamenti = numlin_query($idapp);
 $grp_vicini = array();
@@ -107,7 +109,7 @@ $dati_app['grp_vicini_num'][count($dati_app['grp_vicini_num'])] = count($val_vic
 $dati_app['grp_vicini'][count($dati_app['grp_vicini'])] = ",".implode(",",$val_vicini).",";
 } # fine if ($grp_vicini[$num1])
 } # fine for $num1
-} # fine if (!$dati_app)
+} # fine if (empty($dati_app))
 
 if (!isset($limiti_var['ini']) or (string) $limiti_var['ini'] == "") $limiti_var['ini'] = ($limiti_var['n_fine'] + 1);
 if (!isset($limiti_var['fine']) or (string) $limiti_var['fine'] == "") $limiti_var['fine'] = ($limiti_var['n_ini'] - 1);
