@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -51,7 +51,13 @@ $num_var_mod = count($var_mod);
 
 
 
-function recupera_var_modello_cal ($nome_file,$percorso_cartella_modello,$pag,$fr_frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,$var_per_crea_mod,$anno_modello,$PHPR_TAB_PRE) {
+function recupera_var_modello_cal ($nome_file,$percorso_cartella_modello,$pag,&$fr_frase,&$frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,$var_per_crea_mod,$anno_modello,$lingua_modello,$PHPR_TAB_PRE) {
+
+# Se sono state aggiunte frasi prima dell'uscita di una nuova versione
+/*for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) {
+global ${$fr_frase[$num_fr]};
+${$fr_frase[$num_fr]} = mext_cal($frase[$num_fr],$pag,$lingua_modello);
+} # fine for $num_fr*/
 
 $linee_file = file("$percorso_cartella_modello/$nome_file");
 $num_linee_file = count($linee_file);
@@ -575,6 +581,8 @@ if ($file_js_frame == "https://") $file_js_frame = "";
 if (!preg_match("/^((?!php).)+\.js$/i",$file_js_frame)) $file_js_frame = "";
 
 $num_colori = 0;
+$num_valori = 0;
+$tema_trovato = 0;
 $extra_head_frame = "";
 if (strcmp((string) $tema_modello,"")) {
 include("./includes/templates/$template_data_dir/themes.php");
