@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -129,7 +129,7 @@ elseif ($HTTP_SERVER_VARS['SERVER_PORT']) $SERVER_PORT = $HTTP_SERVER_VARS['SERV
 if ($_SERVER['SERVER_NAME']) $SERVER_NAME = $_SERVER['SERVER_NAME'];
 elseif ($HTTP_SERVER_VARS['SERVER_NAME']) $SERVER_NAME = $HTTP_SERVER_VARS['SERVER_NAME'];
 if ($_SERVER['PHP_SELF']) $PHP_SELF = $_SERVER['PHP_SELF'];
-if ($HTTPS == "on" or $_SERVER['HTTPS'] == "on" or $SERVER_PORT == "443") $url_server = "https://".$SERVER_NAME;
+if ((isset($HTTPS) and $HTTPS == "on") or (isset($_SERVER['HTTPS']) and $_SERVER['HTTPS'] == "on") or (isset($SERVER_PORT) and $SERVER_PORT == "443")) $url_server = "https://".$SERVER_NAME;
 else $url_server = "http://".$SERVER_NAME;
 if ($SERVER_PORT and $SERVER_PORT != "80" and $SERVER_PORT != "443") $url_server .= ":$SERVER_PORT";
 if (substr($PHP_SELF,0,1) != "/") $PHP_SELF = "/".$PHP_SELF;
