@@ -232,10 +232,12 @@ echo "".mex("Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con
 <table style=\"margin-left: auto; margin-right: auto;\" border=\"1\" cellspacing=\"0\" cellpadding=\"4\">";
 $celle = 1;
 $num_colonne = 2;
+$lista_idc_passa = "";
 for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
 if (isset($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) and strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $checked = " checked";
 else $checked = "";
 if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or $checked) {
+$lista_idc_passa .= ",".$dati_ca[$numca]['id'];
 if ($celle == 1) echo "<tr>";
 if ($dati_ca[$numca]['tipo'] == "u") $tipo_costo = "Costo unico";
 if ($dati_ca[$numca]['tipo'] == "s") $tipo_costo = "Costo $parola_settimanale";
@@ -258,6 +260,7 @@ echo "</tr>";
 } # fine if ($celle != 1)
 elseif ($dati_ca['num'] == 0) echo "<tr><td style=\"width: 250px;\">&nbsp;</td></tr>";
 echo "</table><br>";
+if ($lista_idc_passa) echo "<input type=\"hidden\" name=\"lista_idc_passa\" value=\"$lista_idc_passa\">";
 
 $dati_struttura = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'dati_struttura' and idutente = '$id_utente'");
 $dati_struttura = explode("#@&",risul_query($dati_struttura,0,'valpersonalizza'));
