@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2022 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2023 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -49,7 +49,13 @@ $num_var_mod = count($var_mod);
 
 
 
-function recupera_var_modello_rat ($nome_file,$percorso_cartella_modello,$pag,$fr_frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,$var_per_crea_mod,$anno_modello,$PHPR_TAB_PRE) {
+function recupera_var_modello_rat ($nome_file,$percorso_cartella_modello,$pag,&$fr_frase,&$frase,$num_frasi,$var_mod,$num_var_mod,$tipo_periodi,$var_per_crea_mod,$anno_modello,$lingua_modello,$PHPR_TAB_PRE) {
+
+# Se sono state aggiunte frasi prima dell'uscita di una nuova versione
+/*for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) {
+global ${$fr_frase[$num_fr]};
+${$fr_frase[$num_fr]} = mext_rat($frase[$num_fr],$pag,$lingua_modello);
+} # fine for $num_fr*/
 
 $linee_file = file("$percorso_cartella_modello/$nome_file");
 $num_linee_file = count($linee_file);
@@ -297,8 +303,12 @@ if (strtoupper(fixstr($carica_estensione_db)) == $SI) $carica_estensione_db = "S
 else $carica_estensione_db = "NO";
 $M_PHPR_LOAD_EXT = $carica_estensione_db;
 $M_PHPR_TAB_PRE = fixstr($prefisso_tabelle_db);
-$m_stile_soldi = $stile_soldi;
-$m_stile_data = $stile_data;
+$m_stile_soldi = "";
+if ($stile_soldi == mex("europa",$pag)) $m_stile_soldi = "europa";
+if ($stile_soldi == mex("usa",$pag)) $m_stile_soldi = "usa";
+$m_stile_data = "";
+if ($stile_data == mex("europa",$pag)) $m_stile_data = "europa";
+if ($stile_data == mex("usa",$pag)) $m_stile_data = "usa";
 $m_valuta_sing = $fr_Valuta_sing;
 $m_valuta_plur = $fr_Valuta_plur;
 
@@ -550,6 +560,8 @@ if ($file_js_frame == "https://") $file_js_frame = "";
 if (!preg_match("/^((?!php).)+\.js$/i",$file_js_frame)) $file_js_frame = "";
 
 $num_colori = 0;
+$num_valori = 0;
+$tema_trovato = 0;
 $extra_head_frame = "";
 if (strcmp((string) $tema_modello,"")) {
 include("./includes/templates/$template_data_dir/themes.php");
@@ -810,8 +822,10 @@ if (strcmp(\$HOTELD_DB_PASS,\"\")) \$PHPR_DB_PASS = \$HOTELD_DB_PASS;
 if (\$HOTELD_TAB_PRE) \$PHPR_TAB_PRE = \$HOTELD_TAB_PRE;
 ");
 fwrite($file,"\$lingua_modello = \$".mex("var_lingua_modello",$pag).";
+\$stile_soldi = \"\";
 if (\$".mex("var_stile_soldi",$pag)." == \"".mex("europa",$pag)."\") \$stile_soldi = \"europa\";
 if (\$".mex("var_stile_soldi",$pag)." == \"".mex("usa",$pag)."\") \$stile_soldi = \"usa\";
+\$stile_data = \"\";
 if (\$".mex("var_stile_data",$pag)." == \"".mex("europa",$pag)."\") \$stile_data = \"europa\";
 if (\$".mex("var_stile_data",$pag)." == \"".mex("usa",$pag)."\") \$stile_data = \"usa\";
 if (strtoupper(\$".mex("var_anteponi_nome_valuta",$pag).") == \"$SI\") \$anteponi_nome_valuta = \"SI\";
