@@ -23,12 +23,12 @@
 
 global $template_name,$template_name_show,$template_file_name,$template_data_dir;
 $template_name = "rates_table_template";
-$template_name_show = "";
+$template_name_show = array();
 $template_name_show['en'] = "Rates table page";
 $template_name_show['ita'] = "Pagina tabella tariffe";
 $template_name_show['es'] = "Página tabla tarifas";
 $template_class = "rate";
-$template_file_name = "";
+$template_file_name = array();
 $template_file_name['en'] = "rates_table_tpl.php";
 $template_file_name['ita'] = "mdl_tabella_tariffe.php";
 $template_file_name['es'] = "mdl_tabla_tarifas.php";
