@@ -33,7 +33,10 @@ $var_pag[3] = 'tipo_tabella';
 $var_pag[4] = 'torna_indietro';
 $var_pag[5] = 'logout';
 $var_pag[6] = 'vai_anno';
-$n_var_pag = 7;
+$var_pag[7] = 'origine_vecchia';
+$var_pag[8] = 'indietro';
+$var_pag[9] = 'canc_mess_periodi';
+$n_var_pag = 10;
 
 include("./costanti.php");
 include("./includes/funzioni.php");
