@@ -27,29 +27,48 @@ $var_pag = array();
 $var_pag[0] = 'origine';
 $var_pag[1] = 'tipo_tabella';
 $var_pag[2] = 'idmag';
-$var_pag[3] = 'url_enc';
-$var_pag[4] = 'origine_vecchia';
-$var_pag[5] = 'aggiorna_inventario';
-$var_pag[6] = 'manda_form_tab';
-$var_pag[7] = 'tipo_nuova_quantita';
-$var_pag[8] = 'modifica_quantita';
-$var_pag[9] = 'n_id';
-$var_pag[10] = 'n_quantita_min_predef';
-$var_pag[11] = 'n_quantita';
-$var_pag[12] = 'aggiungi_bene';
-$var_pag[13] = 'lista_id_beni_in_mag_passa';
-$var_pag[14] = 'id_bene';
-$var_pag[15] = 'elimina';
-$var_pag[16] = 'elimina_cont';
-$n_var_pag = 17;
-$num2 = 0;
-if (isset($_POST['lista_id_beni_in_mag_passa'])) $num2 = $_POST['lista_id_beni_in_mag_passa'];
-elseif (isset($_GET['lista_id_beni_in_mag_passa'])) $num2 = $_GET['lista_id_beni_in_mag_passa'];
-if ($num2) {
-$num2 = explode(",",$num2);
+$var_pag[3] = 'origine_vecchia';
+$var_pag[4] = 'aggiorna_inventario';
+$var_pag[5] = 'manda_form_tab';
+$var_pag[6] = 'tipo_nuova_quantita';
+$var_pag[7] = 'modifica_quantita';
+$var_pag[8] = 'n_id';
+$var_pag[9] = 'n_quantita_min_predef';
+$var_pag[10] = 'n_quantita';
+$var_pag[11] = 'aggiungi_bene';
+$var_pag[12] = 'lista_id_beni_in_mag_passa';
+$var_pag[13] = 'id_bene';
+$var_pag[14] = 'elimina';
+$var_pag[15] = 'elimina_cont';
+$var_pag[16] = 'crea_ca';
+$var_pag[17] = 'continua';
+$var_pag[18] = 'nome_costo_agg';
+$var_pag[19] = 'n_categoria_ca';
+$var_pag[20] = 'prezzo_costo_agg';
+$var_pag[21] = 'tasseperc_ca';
+$var_pag[22] = 'tipo_categoria_ca';
+$var_pag[23] = 'categoria_esist_ca';
+$var_pag[24] = 'ric_checkin';
+$var_pag[25] = 'ricarica';
+$var_pag[26] = 'lista_magda_passa';
+$var_pag[27] = 'num_appda';
+$n_var_pag = 28;
+if (isset($_REQUEST['lista_id_beni_in_mag_passa'])) {
+$num2 = explode(",",$_REQUEST['lista_id_beni_in_mag_passa']);
 $num3 = count($num2);
 for ($num1 = 0 ; $num1 < $num3 ; $num1++) $var_pag[$n_var_pag++] = "n_quantita".(int) $num2[$num1];
-} # fine if ($num2)
+} # fine if (isset($_REQUEST['lista_id_beni_in_mag_passa']))
+if (isset($_REQUEST['lista_magda_passa'])) {
+$num2 = explode(",",$_REQUEST['lista_magda_passa']);
+$num3 = count($num2);
+for ($num1 = 0 ; $num1 < $num3 ; $num1++) $var_pag[$n_var_pag++] = "mag_da".(int) $num2[$num1];
+} # fine if (isset($_REQUEST['$lista_magda_passa']))
+if (isset($_REQUEST['num_appda'])) $num2 = (int) $_REQUEST['num_appda'];
+else $num2 = 0;
+for ($num1 = 1 ; $num1 <= $num2 ; $num1++) {
+$var_pag[$n_var_pag++] = "app_da$num1";
+$var_pag[$n_var_pag++] = "nome_app_da$num1";
+} # fine for $num2
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -199,6 +218,7 @@ $attiva_regole1_consentite = "n";
 $attiva_tariffe_consentite = "n";
 $attiva_costi_agg_consentiti = "n";
 $priv_ins_costi_agg = "s";
+$utenti_gruppi = "";
 } # fine else if ($id_utente != 1)
 if ($anno_utente_attivato == "SI") {
 
@@ -224,9 +244,10 @@ else include("./includes/head.php");
 $Euro = nome_valuta();
 $frase_modifica = "";
 
-if (empty($url_enc)) $idmag = htmlspecialchars($idmag);
+#if (empty($url_enc)) $idmag = htmlspecialchars($idmag);
+$idmag_url = urlencode($idmag);
+$idmag_orig = htmlspecialchars($idmag);
 $idmag = aggslashdb($idmag);
-$idmag_orig = $idmag;
 if (substr($idmag,0,1) == "a") {
 $idmag = substr($idmag,1);
 $tipoid = "idappartamento";
@@ -244,7 +265,7 @@ $parola_mag = "magazzino";
 $priv_ins_beni = $priv_ins_beni_in_mag;
 $priv_mod_beni = $priv_mod_beni_in_mag;
 } # fine else if (substr($idmag,0,1) == "a")
-$tipo_tabella = htmlspecialchars($tipo_tabella);
+$tipo_tabella = htmlspecialchars(fixstr($tipo_tabella));
 
 $id_esist = esegui_query("select * from $tablemag where $tipoidmag = '$idmag' ");
 if (numlin_query($id_esist) and (($tipoid == "idappartamento" and $priv_vedi_inv_app != "n") or ($tipoid == "idmagazzino" and $priv_vedi_inv_mag != "n"))) {
@@ -330,8 +351,8 @@ $nomi_esist = array();
 $nomecostoagg = $nome_bene;
 $costiagg_esist = esegui_query("select * from $tablenometariffe where nomecostoagg $LIKE '".aggslashdb($nomecostoagg)."%' and idntariffe > 10 ");
 for ($num1 = 0 ; $num1 < numlin_query($costiagg_esist) ; $num1++) $nomi_esist[risul_query($costiagg_esist,$num1,'nomecostoagg')] = 1;
-if ($nomi_esist[$nomecostoagg]) $nomecostoagg .= " *";
-while ($nomi_esist[$nomecostoagg]) $nomecostoagg .= "*";
+if (!empty($nomi_esist[$nomecostoagg])) $nomecostoagg .= " *";
+while (!empty($nomi_esist[$nomecostoagg])) $nomecostoagg .= "*";
 if ($tipoid == "idappartamento") $mag_esist = "app";
 else $mag_esist = "mag$idmag";
 $beniinv_ca_esist = esegui_query("select * from $tablenometariffe where beniinv_ca $LIKE '$mag_esist;%' and beniinv_ca $LIKE '%;$n_id,%' and idntariffe > 10 ");
@@ -344,9 +365,9 @@ echo "<br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventario\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
-<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars($origine_vecchia)."\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixstr($origine_vecchia))."\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixstr($tipo_tabella))."\">
 <input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
 <input type=\"hidden\" name=\"manda_form_tab\" value=\"SI\">
@@ -375,7 +396,7 @@ echo "<div style=\"height: 5px;\"></div>
 ".mex("<em>Prezzo</em> del costo aggiuntivo",$pag).":
  <input type=\"text\" name=\"prezzo_costo_agg\" size=\"8\">$Euro<br>
 <div style=\"height: 5px;\"></div>
-<em>".mex("Tasse",'creaprezzi.php')."</em>: <input type=\"text\" name=\"tasseperc_ca\" value=\"$tasseperc_ca\" size=\"4\">%
+<em>".mex("Tasse",'creaprezzi.php')."</em>: <input type=\"text\" name=\"tasseperc_ca\" size=\"4\">%
  <small>(".mex("il valore del costo si intente con tasse già incluse",'creaprezzi.php').")</small><br>
 <div style=\"height: 5px;\"></div>
 <button class=\"aexc\" type=\"submit\"><div>".mex("Continua",$pag)."</div></button>
@@ -383,9 +404,9 @@ echo "<div style=\"height: 5px;\"></div>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventario\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
-<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars($origine_vecchia)."\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixstr($origine_vecchia))."\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixstr($tipo_tabella))."\">
 <input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br>";
@@ -413,7 +434,7 @@ $tasseperc_ca = formatta_soldi($tasseperc_ca);
 if (controlla_soldi($tasseperc_ca) == "SI" and $tasseperc_ca <= 100 and $tasseperc_ca > 0) {
 esegui_query("update $tablenometariffe set tasseperc_ca = '".aggslashdb($tasseperc_ca)."' where idntariffe = '$idntariffe' ");
 } # fine if (controlla_soldi($tasseperc_ca) == "SI" and $tasseperc_ca <= 100 and $tasseperc_ca > 0)
-if ($tipo_categoria_ca != "ce") $categoria = $n_categoria_ca;
+if (!isset($tipo_categoria_ca) or $tipo_categoria_ca != "ce") $categoria = $n_categoria_ca;
 else $categoria = $categoria_esist_ca;
 if ($categoria) {
 if (@get_magic_quotes_gpc()) $categoria = stripslashes($categoria);
@@ -426,7 +447,7 @@ $frase_modifica .= "<form accept-charset=\"utf-8\" method=\"post\" action=\"modi
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"idntariffe\" value=\"".($idntariffe - 1)."\">
-<input type=\"hidden\" name=\"origine\" value=\"$pag?idmag=$idmag_orig&origine=visualizza_tabelle.php&tipo_tabella=inventario\">
+<input type=\"hidden\" name=\"origine\" value=\"$pag?idmag=$idmag_url&origine=visualizza_tabelle.php&tipo_tabella=inventario\">
 ".mex("Il costo aggiuntivo",'creaprezzi.php')." \"<em>$nome_costo_agg</em>\" ".mex("è stato inserito",'creaprezzi.php').".
  <button class=\"exco\" type=\"submit\"><div>".mex("Modifica il costo",'creaprezzi.php')."</div></button>
 </div></form>";
@@ -552,9 +573,9 @@ mancanti_elem.innerHTML = mancanti_val;
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
-<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars($origine_vecchia)."\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixstr($origine_vecchia))."\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixstr($tipo_tabella))."\">
 <input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
 <input type=\"hidden\" name=\"id_bene\" value=\"$id_bene\">
@@ -565,6 +586,9 @@ else echo mex("del magazzino",$pag);
 echo " <b>$nome_mag</b> ".mex("da",$pag).":<br>
 <table><tr><td>";
 $luogo_da_trovato = "NO";
+$lista_magda_passa = "";
+$lista_appda = "";
+$num_appda = 0;
 for ($num1 = 0 ; $num1 < $num_mag ; $num1++) {
 $idmag_da = risul_query($magazzini,$num1,'idmagazzini');
 if ($tipoid != "idmagazzino" or $idmag_da != $idmag) {
@@ -573,6 +597,7 @@ if (numlin_query($bene_in_mag_da) == 1) {
 $quantita_da = risul_query($bene_in_mag_da,0,'quantita');
 if ($quantita_da > 0) {
 $luogo_da_trovato = "SI";
+$lista_magda_passa .= ",$idmag_da";
 $nome_mag_da = risul_query($magazzini,$num1,'nome_magazzino');
 echo "<br>".mex("magazzino",$pag)." <i>$nome_mag_da</i>:
  <select name=\"mag_da$idmag_da\" id=\"mag_da$idmag_da\" onchange=\"aggiorna_mancanti('mag','$idmag_da')\">
@@ -593,11 +618,13 @@ $quantita_min_predef_da = risul_query($bene_in_app_da,0,'quantita_min_predef');
 $num_diff_da = $quantita_da - $quantita_min_predef_da;
 if ($num_diff_da > 0) {
 $luogo_da_trovato = "SI";
+$num_appda++;
+$lista_appda .= ",$idapp_da";
 echo "<br>".mex("appartamento",'unit.php')." <i>$idapp_da</i>:
- <select name=\"app_da$idapp_da\" id=\"app_da$idapp_da\" onchange=\"aggiorna_mancanti('app','$idapp_da')\">
+ <select name=\"app_da$num_appda\" id=\"app_da$idapp_da\" onchange=\"aggiorna_mancanti('app','$idapp_da')\">
 <option value=\"0\" selected>0</option>";
 for ($num2 = 1 ; $num2 <= $num_diff_da ; $num2++) echo "<option value=\"$num2\">$num2</option>";
-echo "</select><br>";
+echo "</select><input type=\"hidden\" name=\"nome_app_da$num_appda\" value=\"$idapp_da\"><br>";
 } # fine if ($num_diff_da > 0)
 } # fine if (numlin_query($bene_in_app_da) == 1)
 } # fine if ($priv_vedi_inv_app == "s" or $appartamenti_consentiti[$idapp_da] != "NO")
@@ -606,13 +633,15 @@ if ($luogo_da_trovato != "SI") echo "<br>".mex("Nessun posto da cui ricaricare",
 echo "</td><td style=\"width: 50px;\"></td>
 <td valign=\"middle\">".mex("mancanti",$pag).": <span id=\"mancanti\">".($num_diff * -1)."</span></td></tr></table>";
 if ($luogo_da_trovato == "SI") echo "<br><button class=\"xinv\" type=\"submit\"><div>".mex("Continua",$pag)."</div></button>";
-echo "</div></form><br><hr style=\"width: 350px; margin-left: 0; text-align: left;\"><br><br>
+if ($lista_magda_passa) echo "<input type=\"hidden\" name=\"lista_magda_passa\" value=\"$lista_magda_passa\">";
+echo "<input type=\"hidden\" name=\"num_appda\" value=\"$num_appda\">
+</div></form><br><hr style=\"width: 350px; margin-left: 0; text-align: left;\"><br><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
-<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars($origine_vecchia)."\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
+<input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixstr($origine_vecchia))."\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixstr($tipo_tabella))."\">
 <input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form>";
@@ -622,7 +651,7 @@ else {
 $ricaricato = "NO";
 for ($num1 = 0 ; $num1 < $num_mag ; $num1++) {
 $idmag_da = risul_query($magazzini,$num1,'idmagazzini');
-if (${"mag_da".$idmag_da} and controlla_num_pos(${"mag_da".$idmag_da}) == "SI") {
+if (!empty(${"mag_da".$idmag_da}) and controlla_num_pos(${"mag_da".$idmag_da}) == "SI") {
 $bene_in_mag_da = esegui_query("select * from $tablerelinventario where idmagazzino = '$idmag_da' and idbeneinventario = '$id_bene' ");
 if (numlin_query($bene_in_mag_da) == 1) {
 $quantita_da = risul_query($bene_in_mag_da,0,'quantita');
@@ -637,25 +666,30 @@ esegui_query("update $tablerelinventario set quantita = '$quantita' where $tipoi
 } # fine if (numlin_query($bene_in_mag_da) == 1)
 } # fine if (${"mag_da".$idmag_da} and...
 } # fine for $num1
+if (!empty($num_appda)) {
+$num_appda = (int) $num_appda;
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $idapp_da = risul_query($appartamenti,$num1,'idappartamenti');
-if (${"app_da".$idapp_da} and controlla_num_pos(${"app_da".$idapp_da}) == "SI") {
+$num_appda_corr = 0;
+for ($num2 = 1 ; $num2 <= $num_appda ; $num2++) if (htmlspecialchars(${"nome_app_da$num2"}) == $idapp_da) $num_appda_corr = $num2;
+if ($num_appda_corr and !empty(${"app_da$num_appda_corr"}) and controlla_num_pos(${"app_da$num_appda_corr"}) == "SI") {
 if ($priv_vedi_inv_app == "s" or $appartamenti_consentiti[$idapp] != "NO") {
 $bene_in_app_da = esegui_query("select * from $tablerelinventario where idappartamento = '$idapp_da' and idbeneinventario = '$id_bene' ");
 if (numlin_query($bene_in_app_da) == 1) {
 $quantita_da = risul_query($bene_in_app_da,0,'quantita');
 $quantita_min_predef_da = risul_query($bene_in_app_da,0,'quantita_min_predef');
 $num_diff_da = $quantita_da - $quantita_min_predef_da;
-if ($num_diff_da >= ${"app_da".$idapp_da}) {
+if ($num_diff_da >= ${"app_da$num_appda_corr"}) {
 $ricaricato = "SI";
-esegui_query("update $tablerelinventario set quantita = '".($quantita_da - ${"app_da".$idapp_da})."' where idappartamento = '$idapp_da' and idbeneinventario = '$id_bene' ");
-$quantita = $quantita + ${"app_da".$idapp_da};
+esegui_query("update $tablerelinventario set quantita = '".($quantita_da - ${"app_da$num_appda_corr"})."' where idappartamento = '$idapp_da' and idbeneinventario = '$id_bene' ");
+$quantita = $quantita + ${"app_da$num_appda_corr"};
 esegui_query("update $tablerelinventario set quantita = '$quantita' where $tipoid = '$idmag' and idbeneinventario = '$id_bene' ");
-} # fine if ($num_diff_da > ${"app_da".$idapp_da})
+} # fine if ($num_diff_da > ${"app_da$num_appda_corr"})
 } # fine if (numlin_query($bene_in_app_da) == 1)
 } # fine if ($priv_vedi_inv_app == "s" or $appartamenti_consentiti[$idapp] != "NO")
-} # fine if (${"app_da".$idapp_da} and...
+} # fine if ($num_appda_corr and ${"app_da$num_appda_corr"} and...
 } # fine for $num1
+} # fine if (!empty($num_appda))
 if ($ricaricato == "SI") $frase_modifica .= "<b>".mex("Bene ricaricato",$pag)."</b>.<br>";
 } # fine else if ($ricarica != "continua")
 
@@ -683,7 +717,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
 <input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixstr($origine_vecchia))."\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixstr($tipo_tabella))."\">
 <input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
 <input type=\"hidden\" name=\"id_bene\" value=\"$id_bene\">
@@ -748,10 +782,10 @@ for (var n1 = 0; n1 < simb_nq.length; n1++) simb_nq[n1].innerHTML = n_simb;
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventario\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">
+<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars(fixstr($origine))."\">
 <input type=\"hidden\" name=\"origine_vecchia\" value=\"".htmlspecialchars(fixstr($origine_vecchia))."\">
-<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars($tipo_tabella)."\">
-<input type=\"hidden\" name=\"idmag\" value=\"".htmlspecialchars($idmag_orig)."\">
+<input type=\"hidden\" name=\"tipo_tabella\" value=\"".htmlspecialchars(fixstr($tipo_tabella))."\">
+<input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
 <input type=\"hidden\" name=\"manda_form_tab\" value=\"SI\">
 <div class=\"tab_cont\">
@@ -823,9 +857,9 @@ if ($richiesto_checkin == "s") echo "<td>".ucfirst(mex("si",$pag))."</td>";
 else echo "<td>".ucfirst(mex("no",$pag))."</td>";
 } # fine if ($attiva_checkin == "SI")
 echo "<td>";
-if ($priv_mod_beni != "n" and $num_diff < 0) echo "<a href=\"inventario.php?anno=$anno&amp;id_sessione=$id_sessione&amp;origine=".urlencode($origine)."&amp;tipo_tabella=$tipo_tabella&amp;idmag=$idmag_orig&amp;aggiorna_inventario=SI&amp;id_bene=$id_bene_in_mag&amp;ricarica=SI\">".mex("ricarica",$pag)."</a>";
+if ($priv_mod_beni != "n" and $num_diff < 0) echo "<a href=\"inventario.php?anno=$anno&amp;id_sessione=$id_sessione&amp;origine=".urlencode($origine)."&amp;tipo_tabella=$tipo_tabella&amp;idmag=$idmag_url&amp;aggiorna_inventario=SI&amp;id_bene=$id_bene_in_mag&amp;ricarica=SI\">".mex("ricarica",$pag)."</a>";
 if ($priv_mod_beni != "n" and $num_diff < 0 and $priv_ins_beni != "n") echo "<br>";
-if ($priv_ins_beni != "n") echo "<a href=\"inventario.php?anno=$anno&amp;id_sessione=$id_sessione&amp;origine=".urlencode($origine)."&amp;tipo_tabella=$tipo_tabella&amp;idmag=$idmag_orig&amp;aggiorna_inventario=SI&amp;id_bene=$id_bene_in_mag&amp;elimina=SI\">".mex("cancella",$pag)."</a>";
+if ($priv_ins_beni != "n") echo "<a href=\"inventario.php?anno=$anno&amp;id_sessione=$id_sessione&amp;origine=".urlencode($origine)."&amp;tipo_tabella=$tipo_tabella&amp;idmag=$idmag_url&amp;aggiorna_inventario=SI&amp;id_bene=$id_bene_in_mag&amp;elimina=SI\">".mex("cancella",$pag)."</a>";
 if ($priv_ins_beni == "n" and ($num_diff >= 0 or $priv_mod_beni == "n")) echo "&nbsp;";
 echo "</td>";
 } # fine if ($priv_ins_beni != "n" or $priv_mod_beni != "n")
