@@ -37,7 +37,22 @@ $var_pag[9] = 'mese';
 $var_pag[10] = 'tipo_tabella';
 $var_pag[11] = 'torna_indietro';
 $var_pag[12] = 'pagina_messaggi';
-$n_var_pag = 13;
+$var_pag[13] = 'spedisci_messaggio';
+$var_pag[14] = 'destinatario';
+$var_pag[15] = 'ora_visione';
+$var_pag[16] = 'min_visione';
+$var_pag[17] = 'data_visione';
+$var_pag[18] = 'anno_visione';
+$var_pag[19] = 'testo';
+$var_pag[20] = 'origine_vecchia';
+$var_pag[21] = 'indietro';
+$var_pag[22] = 'cambia_dati_ricavati';
+$var_pag[23] = 'n_cognome_richiedente';
+$var_pag[24] = 'n_email_richiedente';
+$var_pag[25] = 'n_data_arrivo';
+$var_pag[26] = 'n_data_partenza';
+$var_pag[27] = 'n_num_persone';
+$n_var_pag = 28;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -366,9 +381,9 @@ $lingue = "";
 
 for ($num1 = 0 ; $num1 < $num_mess ; $num1++) {
 $inbox_id = $info_mess[$num1]->uid;
-/*echo "<b>$num1</b> ".htmlspecialchars("messaggio id: ".$info_mess[$num1]->message_id." / $inbox_id - date: ".$info_mess[$num1]->date." - from: ".$info_mess[$num1]->from." - ").utf8_encode(imap_qprint($info_mess[$num1]->subject))." - ".$info_mess[$num1]->in_reply_to." - ".$info_mess[$num1]->references."<br>";
+echo "<b>$num1</b> ".htmlspecialchars("messaggio id: ".$info_mess[$num1]->message_id." / $inbox_id - date: ".$info_mess[$num1]->date." - from: ".$info_mess[$num1]->from." - ").@utf8_encode(imap_qprint($info_mess[$num1]->subject))." - ".fixset($info_mess[$num1]->in_reply_to)." - ".fixset($info_mess[$num1]->references)."<br>";
 #echo "---------------------------------------------------------<br>".htmlspecialchars(utf8_encode(imap_qprint(imap_body($email_conn,$mess[$num1]))))."<br>";
-echo "<br>";*/
+echo "<br>";
 #$inbox_id_visto = 26742;
 if ($inbox_id > $inbox_id_visto) {
 $mess_nuovi++;
@@ -490,29 +505,29 @@ $fr_date = mex("date",$pag);
 $fr_periodo = mex("periodo",$pag);
 $fr_persone = mex("persone",$pag);
 $lingua_mex = $lingua_orig;
-if (!$arrivo_trovato and !$arrivo_cercato[$fr_arrivo]) {
+if (!$arrivo_trovato and empty($arrivo_cercato[$fr_arrivo])) {
 $arrivo_cercato[$fr_arrivo] = 1;
 # strano syntax error se si rimuove "." (dovuto a riconoscimento array?)
 $arrivo = preg_split("/$fr_arrivo"."[^0-9a-z]/i",$testo);
-if ($arrivo[1]) {
+if (!empty($arrivo[1])) {
 $arrivo = preg_split("/$fr_partenza"."[^0-9a-z]/i",substr($testo,strlen($arrivo[0])));
 $arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2],$lung_resto);
 if ($arrivo) $arrivo_trovato = 1;
-} # fine if ($arrivo[1])
+} # fine if (!empty($arrivo[1]))
 if (!$arrivo_trovato) {
 $arrivo_r = preg_split("/$fr_date"."[^0-9a-z]/i",$testo);
-if ($arrivo_r[1]) {
+if (!empty($arrivo_r[1])) {
 $arrivo = preg_split("/$fr_partenza"."[^0-9a-z]/i",substr($testo,strlen($arrivo_r[0])));
 $arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2],$lung_resto);
 if ($arrivo) $arrivo_trovato = 1;
-} # fine if ($arrivo_r[1])
+} # fine if (!empty($arrivo_r[1]))
 if (!$arrivo_trovato) {
 $arrivo_r = preg_split("/$fr_periodo"."[^0-9a-z]/i",$testo);
-if ($arrivo_r[1]) {
+if (!empty($arrivo_r[1])) {
 $arrivo = preg_split("/$fr_partenza"."[^0-9a-z]/i",substr($testo,strlen($arrivo_r[0])));
 $arrivo = trova_prima_data(substr($arrivo[0],0,40),$stile_data,$lingue[$num2],$lung_resto);
 if ($arrivo) $arrivo_trovato = 1;
-} # fine if ($arrivo_r[1])
+} # fine if (!empty($arrivo_r[1]))
 } # fine if (!$arrivo_trovato)
 if ($arrivo_trovato and !$partenza_trovata) {
 $partenza = substr($testo,((int) $lung_resto + strlen($arrivo_r[0])));
@@ -520,16 +535,16 @@ $partenza = trova_prima_data(substr($partenza,0,40),$stile_data,$lingue[$num2],$
 if ($partenza) $partenza_trovata = 1;
 } # fine if ($arrivo_trovato and !$partenza_trovata)
 } # fine if (!$arrivo_trovato)
-} # fine if (!$arrivo_trovato and !$arrivo_cercato[$fr_arrivo])
-if (!$partenza_trovata and !$partenza_cercata[$fr_partenza]) {
+} # fine if (!$arrivo_trovato and empty($arrivo_cercato[$fr_arrivo]))
+if (!$partenza_trovata and empty($partenza_cercata[$fr_partenza])) {
 $partenza_cercata[$fr_partenza] = 1;
 $partenza = preg_split("/$fr_partenza"."[^0-9a-z]/i",$testo);
 if ($partenza[1]) {
 $partenza = trova_prima_data(substr($testo,strlen($partenza[0]),40),$stile_data,$lingue[$num2],$lung_prima_data);
 if ($partenza and $partenza != $arrivo) $partenza_trovata = 1;
 } # fine if ($partenza[1])
-} # fine if (!$partenza_trovata and !$partenza_cercata[$fr_partenza])
-if (!$num_persone and !$persone_cercate[$fr_persone]) {
+} # fine if (!$partenza_trovata and empty($partenza_cercata[$fr_partenza]))
+if (!$num_persone and empty($persone_cercate[$fr_persone])) {
 $persone_cercate[$fr_persone] = 1;
 $lingua_mex = $lingue[$num2];
 $fr_persone2 = mex("individui",$pag);
@@ -557,7 +572,7 @@ if (!$num_persone) $num_persone = trova_numero_vicino($testo,$fr_viaggiatori);
 } # fine if (!$num_persone)
 } # fine if (!$num_persone)
 } # fine else if ($num_persone)
-} # fine if (!$num_persone and !$persone_cercate[$fr_persone])
+} # fine if (!$num_persone and empty($persone_cercate[$fr_persone]))
 } # fine for $num2
 for ($num2 = 0 ; $num2 < $num_lingue ; $num2++) {
 $lingua_orig = $lingua_mex;
@@ -922,6 +937,11 @@ $dati_calcolati_ca = explode(",",$dati_calcolati[$num2]);
 $prezzo_ca_calc[$n_t][$num2] = (double) $dati_calcolati_ca[0];
 $nome_ca_calc[$n_t][$num2] = $dati_calcolati_ca[1];
 $ripeti_ca_calc[$n_t][$num2] = $dati_calcolati_ca[2];
+$tasseperc_ca_calc[$n_t][$num2] = fixset($dati_calcolati_ca[3]);
+$moltmax_ca_calc[$n_t][$num2] = str_replace("|",",",fixstr($dati_calcolati_ca[4]));
+$valgiornmax_ca_calc[$n_t][$num2] = str_replace("|",",",fixstr($dati_calcolati_ca[5]));
+$giorni_ca_calc[$n_t][$num2] = str_replace("|",",",fixstr($dati_calcolati_ca[6]));
+$tipo_persona_ca_calc[$n_t][$num2] = fixset($dati_calcolati_ca[7]);
 } # fine for $num2
 $numcostiagg[$n_t] = $numcostiagg_dt[($n_t - 1)];
 $idcostoagg_dt2 = explode(",",$idcostoagg_dt[($n_t - 1)]);
@@ -1025,6 +1045,7 @@ $tasto_prenota .= "<input type=\"hidden\" name=\"giorno_stima_checkin$n_t\" valu
 } # fine if ($giorno_stima_checkin)
 } # fine if ($oracheckin)
 $ncostiagg = 0;
+$ngrcostiagg = 0;
 for ($num2 = 0 ; $num2 < $dati_ca['num'] ; $num2++) {
 if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$num2]['id']] == "SI") {
 if ($dati_ca[$num2]['combina'] != "s" and $dati_ca[$num2]['raggruppa'] != "s") {
@@ -1037,17 +1058,22 @@ $tasto_prenota .= "<input type=\"hidden\" name=\"costoagg$ncostiagg"."_$n_t\" va
 } # fine if (isset($costo_presente[$n_t][$dati_ca[$num2]['id']]))
 } # fine if ($dati_ca[$num2]['combina'] != "s" and $dati_ca[$num2]['raggruppa'] != "s")
 else {
+$ngrcostiagg++;
 if (isset($costo_presente[$n_t][$dati_ca[$num2]['id']])) {
 $tasto_prenota .= "<input type=\"hidden\" name=\"gr_idcostoagg".$dati_ca[$num2]['id']."_$n_t\" value=\"SI\">
 <input type=\"hidden\" name=\"gr_numsettimane".$dati_ca[$num2]['id']."_$n_t\" value=\"".$numsettimane[$n_t][$dati_ca[$num2]['id']]."\">
 <input type=\"hidden\" name=\"gr_nummoltiplica_ca".$dati_ca[$num2]['id']."_$n_t\" value=\"".$nummoltiplica_ca[$n_t][$dati_ca[$num2]['id']]."\">
-<input type=\"hidden\" name=\"gr_catpers_ca".$dati_ca[$num2]['id']."_$n_t\" value=\"".$catpers_ca[$n_t][$dati_ca[$num2]['id']]."\">";
+<input type=\"hidden\" name=\"gr_catpers_ca".$dati_ca[$num2]['id']."_$n_t\" value=\"".$catpers_ca[$n_t][$dati_ca[$num2]['id']]."\">
+<input type=\"hidden\" name=\"idca_ngr_passa$ngrcostiagg"."_$n_t\" value=\"".$dati_ca[$num2]['id']."\">";
 } # fine if (isset($costo_presente[$n_t][$dati_ca[$num2]['id']]))
 } # fine else if ($dati_ca[$num2]['combina'] != "s" and $dati_ca[$num2]['raggruppa'] != "s")
 } # fine if ($attiva_costi_agg_consentiti == "n" or...
 } # fine for $num2
 } # fine for $n_t
-$tasto_prenota .= "<button class=\"ires\" type=\"submit\"><div>".mex("Inserisci la prenotazione",$pag)."</div></button>
+$tasto_prenota .= "<input type=\"hidden\" name=\"numcostiagg\" value=\"$ncostiagg\">
+<input type=\"hidden\" name=\"numgrca_passa\" value=\"$ngrcostiagg\">
+<input type=\"hidden\" name=\"num_categorie_persone\" value=\"".count($cat_numpers[1])."\">
+<button class=\"ires\" type=\"submit\"><div>".mex("Inserisci la prenotazione",$pag)."</div></button>
 </div></form><br>";
 
 if ($num_tipologie == 1 and !$numero_tariffa[1] and $num_app_tipo_richiesti[1] == 1 and $fineperiodo[1]) {
@@ -1077,7 +1103,7 @@ for ($n_r = 1 ; $n_r <= $num_app_tipo_richiesti[$n_t] ; $n_r++) {
 $n_c++;
 $tasto_contr .= "<input type=\"hidden\" name=\"cognome_$n_c\" value=\"$cognome_richiedente\">
 <input type=\"hidden\" name=\"nome_$n_c\" value=\"$nome_richiedente\">
-<input type=\"hidden\" name=\"datanascita_$n_c\" value=\"$datanascita\">
+<input type=\"hidden\" name=\"data_nascita_$n_c\" value=\"$datanascita\">
 <input type=\"hidden\" name=\"documento_$n_c\" value=\"$documento\">
 <input type=\"hidden\" name=\"tipo_documento_$n_c\" value=\"$tipodoc\">
 <input type=\"hidden\" name=\"sesso_$n_c\" value=\"$sesso\">
@@ -1104,13 +1130,20 @@ $tasto_contr .= "<input type=\"hidden\" name=\"cognome_$n_c\" value=\"$cognome_r
 <input type=\"hidden\" name=\"costo_tariffa_$n_c\" value=\"".$costo_tariffa[$n_t]."\">
 <input type=\"hidden\" name=\"caparra_$n_c\" value=\"".$caparra[$n_t]."\">
 <input type=\"hidden\" name=\"n_letti_agg_$n_c\" value=\"".$letti_agg[$n_t]."\">";
+if ($n_t == $num_tipologie and $n_r == $num_app_tipo_richiesti[$n_t]) $tasto_contr .= "<input type=\"hidden\" name=\"ultima_prenotazione_per_cliente_$n_c\" value=\"1\">";
+else $tasto_contr .= "<input type=\"hidden\" name=\"ultima_prenotazione_per_cliente_$n_c\" value=\"0\">";
 $costo_tot = (double) $costo_tariffa[$n_t];
 $num_costi_agg = 0;
 for ($num2 = 1 ; $num2 < $num_ca_calc[$n_t] ; $num2++) {
 if (!$ripeti_ca_calc[$n_t][$num2] or $ripeti_ca_calc[$n_t][$num2] >= $n_r) {
 $costo_tot = (double) ($costo_tot + $prezzo_ca_calc[$n_t][$num2]);
 $tasto_contr .= "<input type=\"hidden\" name=\"nome_costo_agg$num_costi_agg"."_$n_c\" value=\"".$nome_ca_calc[$n_t][$num2]."\">
-<input type=\"hidden\" name=\"val_costo_agg$num_costi_agg"."_$n_c\" value=\"".$prezzo_ca_calc[$n_t][$num2]."\">";
+<input type=\"hidden\" name=\"val_costo_agg$num_costi_agg"."_$n_c\" value=\"".$prezzo_ca_calc[$n_t][$num2]."\">
+<input type=\"hidden\" name=\"percentuale_tasse_costo_agg$num_costi_agg"."_$n_c\" value=\"".$tasseperc_ca_calc[$n_t][$num2]."\">
+<input type=\"hidden\" name=\"moltiplica_max_costo_agg$num_costi_agg"."_$n_c\" value=\"".$moltmax_ca_calc[$n_t][$num2]."\">
+<input type=\"hidden\" name=\"valore_giornaliero_max_costo_agg$num_costi_agg"."_$n_c\" value=\"".$valgiornmax_ca_calc[$n_t][$num2]."\">";
+if ($giorni_ca_calc[$n_t][$num2]) $tasto_contr .= "<input type=\"hidden\" name=\"giorni_costo_agg$num_costi_agg"."_$n_c\" value=\"".$giorni_ca_calc[$n_t][$num2]."\">";
+if ($tipo_persona_ca_calc[$n_t][$num2]) $tasto_contr .= "<input type=\"hidden\" name=\"tipo_persona_costo_agg$num_costi_agg"."_$n_c\" value=\"".$tipo_persona_ca_calc[$n_t][$num2]."\">";
 $num_costi_agg++;
 } # fine if (!$ripeti_ca_calc[$n_t][$num2] or $ripeti_ca_calc[$n_t][$num2] >= $n_r)
 } # fine for $num2
