@@ -39,7 +39,8 @@ $var_pag[11] = 'commentofoto';
 $var_pag[12] = 'numfoto';
 $var_pag[13] = 'n_commento_ita';
 $var_pag[14] = 'cancurlfoto';
-$n_var_pag = 15;
+$var_pag[15] = 'MAX_FILE_SIZE';
+$n_var_pag = 16;
 $num2 = 0;
 if (isset($_POST['num_app_modifica'])) $num2 = (int) $_POST['num_app_modifica'];
 elseif (isset($_GET['num_app_modifica'])) $num2 = (int) $_GET['num_app_modifica'];
@@ -415,7 +416,8 @@ $n_maxoccupanti = fixset(${"n_maxoccupanti".$num1});
 $n_priorita = ${"n_priorita".$num1};
 $n_app_vicini = ${"n_app_vicini".$num1};
 ${"d_app_vicini".$num1} = esegui_query("select app_vicini from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."' ");
-if (numlin_query(${"d_app_vicini".$num1})) ${"d_app_vicini".$num1} = risul_query(${"d_app_vicini".$num1},0,'app_vicini');
+if (numlin_query(${"d_app_vicini".$num1})) ${"d_app_vicini".$num1} = (string) risul_query(${"d_app_vicini".$num1},0,'app_vicini');
+else ${"d_app_vicini".$num1} = "";
 
 if ($cambia_nome_app and $modificaappartamento == "Continua") {
 $anni_esistenti2 = esegui_query("select * from $tableanni order by idanni");
@@ -482,7 +484,7 @@ $n_numpiano = ${"n_numpiano".$num1};
 $n_maxoccupanti = ${"n_maxoccupanti".$num1};
 $n_priorita = ${"n_priorita".$num1};
 $n_app_vicini = (string) ${"n_app_vicini".$num1};
-$d_app_vicini = (string) ${"d_app_vicini".$num1};
+$d_app_vicini = ${"d_app_vicini".$num1};
 $n_commento = ${"n_commento".$num1};
 if ($form_tabella) {
 $comp_nome_app = (string) ${"idappartamenti".$num1};
