@@ -30,15 +30,20 @@ $var_pag[2] = 'modifica';
 $var_pag[3] = 'tipo_tabella';
 $n_var_pag = 4;
 $num2 = 0;
-if (isset($_POST['id_prenota'])) $num2 = (int) $_POST['id_prenota'];
-elseif (isset($_GET['id_prenota'])) $num2 = (int) $_GET['id_prenota'];
+if (isset($_POST['id_prenota'])) $num2 = $_POST['id_prenota'];
+elseif (isset($_GET['id_prenota'])) $num2 = $_GET['id_prenota'];
 if ($num2) {
+$num7 = explode(",",$num2);
+$num8 = count($num7);
+for ($num6 = 0 ; $num6 < $num8 ; $num6++) {
+$num2 = (int) $num7[$num6];
 $var_pag[$n_var_pag++] = "num_ospiti_inviati$num2";
 $var_pag[$n_var_pag++] = "principale$num2";
 $var_pag[$n_var_pag++] = "nazione$num2"."_1";
 $var_pag[$n_var_pag++] = "regione$num2"."_1";
 $var_pag[$n_var_pag++] = "citta$num2"."_1";
 $var_pag[$n_var_pag++] = "documento$num2"."_1";
+$var_pag[$n_var_pag++] = "tipodoc$num2"."_1";
 $var_pag[$n_var_pag++] = "giornoscaddoc$num2"."_1";
 $var_pag[$n_var_pag++] = "mesescaddoc$num2"."_1";
 $var_pag[$n_var_pag++] = "annoscaddoc$num2"."_1";
@@ -46,6 +51,7 @@ $var_pag[$n_var_pag++] = "nazionedoc$num2"."_1";
 $var_pag[$n_var_pag++] = "regionedoc$num2"."_1";
 $var_pag[$n_var_pag++] = "cittadoc$num2"."_1";
 $var_pag[$n_var_pag++] = "id_osp_num$num2"."_0";
+$var_pag[$n_var_pag++] = "num_altri_ospiti_passa$num2";
 $num4 = 0;
 if (isset($_POST["id_osp_num$num2"."_0"])) $num4 = (int) $_POST["id_osp_num$num2"."_0"];
 elseif (isset($_GET["id_osp_num$num2"."_0"])) $num4 = (int) $_GET["id_osp_num$num2"."_0"];
@@ -75,6 +81,17 @@ $var_pag[$n_var_pag++] = "ospite$num2"."_$num4";
 $var_pag[$n_var_pag++] = "parentela_$num2"."_$num4";
 } # fine if ($num4)
 } # fine for $num1
+$num3 = 0;
+if (isset($_POST["num_altri_ospiti_passa$num2"])) $num3 = (int) $_POST["num_altri_ospiti_passa$num2"];
+elseif (isset($_GET["num_altri_ospiti_passa$num2"])) $num3 = (int) $_GET["num_altri_ospiti_passa$num2"];
+for ($num1 = 0 ; $num1 < $num3 ; $num1++) {
+$var_pag[$n_var_pag++] = "id_altro_osp_num$num2"."_$num1";
+$num4 = 0;
+if (isset($_POST["id_altro_osp_num$num2"."_$num1"])) $num4 = (int) $_POST["id_altro_osp_num$num2"."_$num1"];
+elseif (isset($_GET["id_altro_osp_num$num2"."_$num1"])) $num4 = (int) $_GET["id_altro_osp_num$num2"."_$num1"];
+if ($num4) $var_pag[$n_var_pag++] = "altro_ospite$num2"."_$num4";
+} # fine for $num1
+} # fine for $num6
 } # fine if ($num2)
 
 include("./costanti.php");
@@ -319,14 +336,14 @@ $presente_id[$idclienti] = "SI";
 $idclienti_compagni .= substr($compagni_cliente,1);
 $principale = $idclienti;
 } # fine if (isset(${"cliente_ospite".$id_prenota."_".$idclienti}) and ${"cliente_ospite".$id_prenota."_".$idclienti} == "SI")
-else if (${"id_osp_num".$id_prenota."_1"} == $idclienti) esegui_query("delete from $tablerclientiprenota where idprenota = '$id_prenota' and idclienti = '$idclienti' ");
+elseif (isset(${"id_osp_num".$id_prenota."_1"}) and ${"id_osp_num".$id_prenota."_1"} == $idclienti) esegui_query("delete from $tablerclientiprenota where idprenota = '$id_prenota' and idclienti = '$idclienti' ");
 
 $ospiti = esegui_query("select idclienti,num_ordine,parentela from $tablerclientiprenota where idprenota = '$id_prenota' order by num_ordine ");
 $d_num_ospiti = numlin_query($ospiti);
 for ($num1 = 0 ; $num1 < $d_num_ospiti ; $num1++) $osp_presente[risul_query($ospiti,$num1,'idclienti')] = ($num1 + 1);
 
 if ($principale != $idclienti) {
-if ($osp_presente[$principale] and ${"ospite".$id_prenota."_".$principale} == "SI") {
+if (!empty($osp_presente[$principale]) and ${"ospite".$id_prenota."_".$principale} == "SI") {
 if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0) $mess_letto = 1;
 else {
 $num_ospiti++;
@@ -334,7 +351,7 @@ $lista_ospiti[$num_ospiti] = $principale;
 $lista_ospiti['lista'] .= $principale.",";
 $presente_id[$principale] = "SI";
 } # fine else if ($app_letto_idpr[$num_idpr] and $num_ospiti > 0)
-} # fine if ($osp_presente[$principale] and ${"ospite".$id_prenota."_".$principale} == "SI")
+} # fine if (!empty($osp_presente[$principale]) and ${"ospite".$id_prenota."_".$principale} == "SI")
 else $principale = "";
 } # fine if ($principale != $idclienti)
 
@@ -357,7 +374,7 @@ $num_ospiti++;
 $lista_ospiti[$num_ospiti] = $id_clienti_osp;
 $lista_ospiti['lista'] .= $id_clienti_osp.",";
 $presente_id[$id_clienti_osp] = "SI";
-$parentela = ${"parentela_".$id_prenota."_".$id_clienti_osp};
+$parentela = fixstr(${"parentela_".$id_prenota."_".$id_clienti_osp});
 if (@get_magic_quotes_gpc()) $parentela = stripslashes($parentela);
 $parentela = htmlspecialchars($parentela);
 $d_parentela = risul_query($ospiti,($osp_presente[$id_clienti_osp] - 1),'parentela');
@@ -440,7 +457,7 @@ if (empty($osp_presente[$id_clienti_osp])) {
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if ($n_num_ordine > 2) {
 if (@get_magic_quotes_gpc()) $n_parentela[$num1] = stripslashes($n_parentela[$num1]);
-$parentela = htmlspecialchars($n_parentela[$num1]);
+$parentela = htmlspecialchars(fixstr($n_parentela[$num1]));
 } # fine if ($n_num_ordine > 2)
 else $parentela = "";
 esegui_query("insert into $tablerclientiprenota (idprenota,idclienti,num_ordine,parentela,datainserimento,hostinserimento,utente_inserimento) values ('$id_prenota','$id_clienti_osp','$n_num_ordine','$parentela','$datainserimento','$HOSTNAME','$id_utente_ins') ");
@@ -554,7 +571,8 @@ $mostra_osp = "NO";
 $cliente_ospite = "SI";
 $dati_ospite = $dati_cliente;
 } # fine if ($num_ord == 1 and..
-else echo "<br><label><input name=\"cliente_ospite".$id_prenota."_".$idclienti."\" value=\"SI\" type=\"checkbox\"> ".mex("Ospite della prenotazione",$pag)."</label><br>";
+else echo "<br><input type=\"hidden\" name=\"id_osp_num$id_prenota"."_0\" value=\"$idclienti\">
+<label><input name=\"cliente_ospite".$id_prenota."_".$idclienti."\" value=\"SI\" type=\"checkbox\"> ".mex("Ospite della prenotazione",$pag)."</label><br>";
 } # fine if ($num1 == 0)
 if ($mostra_osp == "SI") {
 $dati_ospite = esegui_query("select * from $tableclienti where idclienti = '$id_clienti_osp' ");
@@ -691,7 +709,7 @@ $id_clienti_osp = $idclienti_compagni[$num1];
 if (!isset($presente_id[$id_clienti_osp]) or $presente_id[$id_clienti_osp] != "SI") {
 $presente_id[$id_clienti_osp] = "SI";
 $dati_ospite = esegui_query("select cognome,nome,sesso,datanascita,utente_inserimento from $tableclienti where idclienti = '$id_clienti_osp' ");
-$dati_osp .= "<input name=\"altro_ospite$id_prenota"."_$id_clienti_osp\" value=\"SI\" type=\"checkbox\">\
+$dati_osp .= "<label><input name=\"altro_ospite$id_prenota"."_$id_clienti_osp\" value=\"SI\" type=\"checkbox\"><input type=\"hidden\" name=\"id_altro_osp_num$id_prenota"."_$num1\" value=\"$id_clienti_osp\">\
  <em>".addslashes(risul_query($dati_ospite,0,'cognome'))."</em> ";
 $ccnome = addslashes(risul_query($dati_ospite,0,'nome'));
 $ccsesso = risul_query($dati_ospite,0,'sesso');
@@ -700,11 +718,11 @@ $O = "o";
 if ($ccsesso == "f") $O = "a";
 if ($ccnome) $dati_osp .=  "$ccnome ";
 if ($ccdatanascita) $dati_osp .= mex("nat$O il",$pag)." ".formatta_data($ccdatanascita,$stile_data)." ";
-$dati_osp .= "<br>";
+$dati_osp .= "</label><br>";
 } # fine if (!isset($presente_id[$id_clienti_osp]) or $presente_id[$id_clienti_osp] != "SI")
 } # fine for $num1
 if ($dati_osp) {
-echo "
+echo "<input type=\"hidden\" name=\"num_altri_ospiti_passa$id_prenota\" value=\"$num_idclienti_compagni\">
 <script type=\"text/javascript\">
 <!--
 function apri_osp$id_prenota () {
