@@ -95,7 +95,11 @@ $var_pag[67] = 'sposta_giu';
 $var_pag[68] = 'elimina_cond';
 $var_pag[69] = 'arr_pers_elimina';
 $var_pag[70] = 'elimina_arr_pers';
-$n_var_pag = 71;
+$var_pag[71] = 'mod_contr_importa';
+$var_pag[72] = 'tipo_contr_imp';
+$var_pag[73] = 'contr_imp';
+$var_pag[74] = 'agg_se';
+$n_var_pag = 75;
 $num2 = 0;
 if (isset($_POST['num_se'])) $num2 = (int) $_POST['num_se'];
 elseif (isset($_GET['num_se'])) $num2 = (int) $_GET['num_se'];
@@ -136,6 +140,7 @@ if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
 else $modifica_pers = "SI";
 $priv_mod_doc = substr($priv_mod_pers,2,1);
 $priv_mod_doc_api = substr($priv_mod_pers,4,1);
+$priv_mod_doc_html = substr($priv_mod_pers,9,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
@@ -150,6 +155,7 @@ $anno_utente_attivato = "SI";
 $modifica_pers = "SI";
 $priv_mod_doc = "s";
 $priv_mod_doc_api = "s";
+$priv_mod_doc_html = "s";
 $attiva_contratti_consentiti = "n";
 } # fine else if ($id_utente != 1)
 
@@ -169,12 +175,16 @@ $stile_data = stile_data();
 if (!isset($contr_cond) or controlla_num_pos($contr_cond) == "NO" or $contr_cond < 1) $contr_cond = "";
 if ($attiva_contratti_consentiti != "n" and $contratti_consentiti_vett[$contr_cond] != "SI") $contr_cond = "";
 if (strcmp((string) $contr_cond,"")) {
-$contr_cond_esist = esegui_query("select numero from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo $LIKE 'contr%' ");
+$contr_cond = (int) $contr_cond;
+$contr_cond_esist = esegui_query("select tipo from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo $LIKE 'contr%' ");
 if (numlin_query($contr_cond_esist) != 1) $contr_cond = "";
-elseif ($priv_mod_doc_api != "s") {
+else {
+if ($priv_mod_doc_html != "s" and risul_query($contr_cond_esist,0,'tipo') == "contrhtm") $contr_cond = "";
+if ($contr_cond and $priv_mod_doc_api != "s") {
 $api_esistente = esegui_query("select * from $tablecontratti where numero = '".aggslashdb($contr_cond)."' and tipo = 'api'");
 if (numlin_query($api_esistente)) $contr_cond = "";
-} # fine elseif ($priv_mod_doc_api != "s")
+} # fine if ($contr_cond and $priv_mod_doc_api != "s")
+} # fine else if (numlin_query($contr_cond_esist) != 1)
 } # fine if (strcmp((string) $contr_cond,""))
 
 include("./includes/funzioni_mod_contratti.php");
@@ -226,6 +236,7 @@ if (isset($num_se) and $num_se > 80) $num_se = 80;
 
 
 if (!empty($cambia_qualcosa)) {
+$mostra_form_iniziale = "";
 
 
 if (!empty($aggiungi_var_pers)) {
@@ -507,11 +518,13 @@ if (!isset($cond_sempre) or $cond_sempre != "SI") {
 if ($num_se > 1) $testo .= $and_or;
 for ($num1 = 1 ; $num1 <= $num_se ; $num1++) {
 controlla_var_se(${"var_se".$num1},$continua,$var_predef,$num_var_predef,$contr_cond);
-if (${"cond".$num1} != "=" and ${"cond".$num1} != "!=" and ${"cond".$num1} != "mag" and ${"cond".$num1} != "min" and ${"cond".$num1} != "con" and ${"cond".$num1} != "cmm") $continua = "NO";
+if (${"cond".$num1} != "=" and ${"cond".$num1} != "!=" and ${"cond".$num1} != "mag" and ${"cond".$num1} != "min" and ${"cond".$num1} != "con" and ${"cond".$num1} != "cmm" and ${"cond".$num1} != "nco" and ${"cond".$num1} != "ncm") $continua = "NO";
 if (${"cond".$num1} == "mag") ${"cond".$num1} = ">";
 if (${"cond".$num1} == "min") ${"cond".$num1} = "<";
 if (${"cond".$num1} == "con") ${"cond".$num1} = "{}";
 if (${"cond".$num1} == "cmm") ${"cond".$num1} = "{A}";
+if (${"cond".$num1} == "nco") ${"cond".$num1} = "!{}";
+if (${"cond".$num1} == "ncm") ${"cond".$num1} = "!{A}";
 if (${"tipo_val_se".$num1} != "txt" and ${"tipo_val_se".$num1} != "var") $continua = "NO";
 if (${"tipo_val_se".$num1} == "txt") $val_se = controlla_testo_input(${"val_se_txt".$num1});
 else $val_se = controlla_var_se(${"val_se_sel".$num1},$continua,$var_predef,$num_var_predef,$contr_cond);
@@ -805,7 +818,7 @@ $nomi_contratti = explode("#@&",risul_query($nomi_contratti,0,'valpersonalizza')
 $num_nomi_contratti = count($nomi_contratti);
 for ($num1 = 0 ; $num1 < $num_nomi_contratti ; $num1++) {
 $dati_nome_contratto = explode("#?&",$nomi_contratti[$num1]);
-$nome_contratto[$dati_nome_contratto[0]] = $dati_nome_contratto[1];
+$nome_contratto[$dati_nome_contratto[0]] = fixset($dati_nome_contratto[1]);
 } # fine for $num1
 if (!$contr_cond) {
 $sel = " selected";
@@ -962,6 +975,8 @@ if ($se_cond_corr[1] == ">") $str_cond .= mex("è maggiore di",$pag);
 if ($se_cond_corr[1] == "<") $str_cond .= mex("è minore di",$pag);
 if ($se_cond_corr[1] == "{}") $str_cond .= mex("contiene",$pag);
 if ($se_cond_corr[1] == "{A}") $str_cond .= mex("contiene",$pag)." (".mex("maiusc./minusc.",$pag).")";
+if ($se_cond_corr[1] == "!{}") $str_cond .= mex("non contiene",$pag);
+if ($se_cond_corr[1] == "!{A}") $str_cond .= mex("non contiene",$pag)." (".mex("maiusc./minusc.",$pag).")";
 if ($se_cond_corr[2] == "var") $str_cond .= " [".mexv($se_cond_corr[3])."] ";
 else $str_cond .= " \"".htmlspecialchars($se_cond_corr[3])."\" ";
 if (isset($num_cond_mod) and $num_cond_mod == $num_cond) {
@@ -971,6 +986,8 @@ if (${"cond".$num2} == ">") ${"cond".$num2} = "mag";
 if (${"cond".$num2} == "<") ${"cond".$num2} = "min";
 if (${"cond".$num2} == "{}") ${"cond".$num2} = "con";
 if (${"cond".$num2} == "{A}") ${"cond".$num2} = "cmm";
+if (${"cond".$num2} == "!{}") ${"cond".$num2} = "nco";
+if (${"cond".$num2} == "!{A}") ${"cond".$num2} = "ncm";
 ${"tipo_val_se".$num2} = $se_cond_corr[2];
 if ($se_cond_corr[2] == "var") ${"val_se_sel".$num2} = $se_cond_corr[3];
 else ${"val_se_txt".$num2} = $se_cond_corr[3];
@@ -1390,6 +1407,8 @@ $sel_mag = "";
 $sel_min = "";
 $sel_con = "";
 $sel_cmm = "";
+$sel_nco = "";
+$sel_ncm = "";
 if (isset(${"cond".$num1})) {
 if (${"cond".$num1} == "=") $sel_ug = " selected";
 if (${"cond".$num1} == "!=") $sel_div = " selected";
@@ -1397,6 +1416,8 @@ if (${"cond".$num1} == "mag") $sel_mag = " selected";
 if (${"cond".$num1} == "min") $sel_min = " selected";
 if (${"cond".$num1} == "con") $sel_con = " selected";
 if (${"cond".$num1} == "cmm") $sel_cmm = " selected";
+if (${"cond".$num1} == "nco") $sel_nco = " selected";
+if (${"cond".$num1} == "ncm") $sel_ncm = " selected";
 } # fine if (isset(${"cond".$num1}))
 echo "<td>$fr_se</td><td><select name=\"var_se$num1\">
 ".str_replace("\"".fixset(${"var_se".$num1})."\">","\"".fixset(${"var_se".$num1})."\" selected>",$option_var_predef)."
@@ -1407,6 +1428,8 @@ echo "<td>$fr_se</td><td><select name=\"var_se$num1\">
 <option value=\"min\"$sel_min>".mex("è minore di",$pag)."</option>
 <option value=\"con\"$sel_con>".mex("contiene",$pag)."</option>
 <option value=\"cmm\"$sel_cmm>".mex("contiene",$pag)." (".mex("maiusc./minusc.",$pag).")</option>
+<option value=\"nco\"$sel_nco>".mex("non contiene",$pag)."</option>
+<option value=\"ncm\"$sel_ncm>".mex("non contiene",$pag)." (".mex("maiusc./minusc.",$pag).")</option>
 </select></td><td><b style=\"font-size: 260%;\">{</b></td><td>
 <table cellspacing=\"0\"><tr><td>
 <input type=\"radio\" id=\"val_se_txt$num1\" name=\"tipo_val_se$num1\" value=\"txt\"$chk_txt></td><td>
