@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,9 +23,16 @@
 $pag = "mostra_sorgente.php";
 $titolo = "HotelDruid: Source Code";
 
+$var_pag = array();
+$var_pag[0] = 'file_sorgente';
+$var_pag[1] = 'raw';
+$n_var_pag = 2;
+
 include("./costanti.php");
 include("./includes/funzioni.php");
 include("./includes/files_sorgente.php");
+if (!isset($raw)) $raw = "";
+$mostra_lista = "";
 
 
 if ($raw != "SI") {
@@ -39,7 +46,7 @@ else include("./includes/head.php");
 } # fine if ($raw != "SI")
 
 
-if ($file_sorgente and substr($file_sorgente,-1) != "/") {
+if (!empty($file_sorgente) and substr($file_sorgente,-1) != "/") {
 $file_trovato = "NO";
 reset($files_sorgente);
 foreach ($files_sorgente as $f_s) if ($file_sorgente == $f_s) $file_trovato = "SI";
@@ -62,7 +69,7 @@ else echo "<div style=\"word-break: break-word; line-height: 1.2;\">".nl2br(html
 } # fine else if (substr($file_sorgente,-4) == ".png" or...
 } # fine if (@is_file($file_sorgente))
 } # fine if ($file_trovato == "SI")
-} # fine if ($file_sorgente and...
+} # fine if (!empty($file_sorgente) and...
 
 
 
