@@ -46,7 +46,8 @@ $var_pag[17] = 'moltiplica';
 $var_pag[18] = 'origine_vecchia';
 $var_pag[19] = 'torna_indietro';
 $var_pag[20] = 'indietro';
-$n_var_pag = 21;
+$var_pag[21] = 'canc_idprenota';
+$n_var_pag = 22;
 $num2 = 0;
 if (isset($_POST['num_costi_passa'])) $num2 = (int) $_POST['num_costi_passa'];
 elseif (isset($_GET['num_costi_passa'])) $num2 = (int) $_GET['num_costi_passa'];
@@ -237,6 +238,7 @@ $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 $d_caparra = 0;
 $d_num_persone = 0;
+$num_letti_agg = array('max' => 0);
 
 
 if (!empty($canc_idprenota) or !empty($azzera)) $id_prenota = "";
@@ -289,7 +291,6 @@ $d_num_persone = risul_query($dati_prenota,0,'num_persone');
 if (!$d_num_persone) $d_num_persone = 0;
 $d_cat_persone = dati_cat_pers_p($dati_prenota,0,$dati_cat_pers,$d_num_persone);
 $d_tariffesettimanali = risul_query($dati_prenota,0,'tariffesettimanali');
-unset($num_letti_agg);
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota,$dati_cat_pers);
 $d_costo_agg_tot = (double) 0;
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
@@ -502,7 +503,7 @@ else {
 $idinizioperiodo = $id_periodo_corrente;
 $idfineperiodo = $id_periodo_corrente;
 $settimane_costo[$num_costo] = calcola_settimane_costo($tableperiodi,$dati_ca,$numca,$idinizioperiodo,$idfineperiodo,",$id_periodo_corrente,","1");
-calcola_moltiplica_costo($dati_ca,$numca,$moltiplica_costo[$num_costo],$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],$molt_costo,"1","","");
+calcola_moltiplica_costo($dati_ca,$numca,$moltiplica_costo[$num_costo],$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],$molt_costo,"1","",$num_letti_agg);
 if (trova_periodo_permesso_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,"1") == "NO") {
 if ($dati_ca[$numca]['combina'] == "s") continue;
 $errori_costi[$num_costo] .= ", ".mex("periodo non permesso",$pag);
@@ -1290,7 +1291,7 @@ unset($costi_agg_raggr);
 $onclick_ins_js = array();
 unset($combina_mostrato);
 for ($num1 = 0 ; $num1 < $dati_ca['num'] ; $num1++) {
-if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$num1]['id']] == "SI") {
+if ($attiva_costi_agg_consentiti == "n" or (isset($costi_agg_consentiti_vett[$dati_ca[$num1]['id']]) and $costi_agg_consentiti_vett[$dati_ca[$num1]['id']] == "SI")) {
 $testo_costo = "";
 $nome_costo = $dati_ca[$num1]['nome'];
 $id_costo = $dati_ca[$num1]['id'];
