@@ -36,7 +36,10 @@ $var_pag[8] = 'continua';
 $var_pag[9] = 'id_transazione';
 $var_pag[10] = 'pagina_prenota';
 $var_pag[11] = 'cambia_colori';
-$n_var_pag = 12;
+$var_pag[12] = 'tipo_tabella';
+$var_pag[13] = 'torna_indietro';
+$var_pag[14] = 'show_bar';
+$n_var_pag = 15;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -62,6 +65,7 @@ if ($id_utente) {
 if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
+$prendi_gruppi = "";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
