@@ -41,7 +41,18 @@ $var_pag[13] = 'numtariffa1';
 $var_pag[14] = 'tariffa_sel1';
 $var_pag[15] = 'cambia_mostra_tab';
 $var_pag[16] = 'n_tar_passa';
-$n_var_pag = 17;
+$var_pag[17] = 'azione';
+$var_pag[18] = 'aggurlfoto';
+$var_pag[19] = 'n_urlfoto';
+$var_pag[20] = 'MAX_FILE_SIZE';
+$var_pag[21] = 'cancurlfoto';
+$var_pag[22] = 'numfoto';
+$var_pag[23] = 'commentofoto';
+$var_pag[24] = 'n_commento_ita';
+$var_pag[25] = 'modificadescr';
+$var_pag[26] = 'n_descrizione_ita';
+$var_pag[27] = 'n_per_passa';
+$n_var_pag = 28;
 $num2 = 0;
 if (isset($_POST['num_tariffe_mostra'])) $num2 = (int) $_POST['num_tariffe_mostra'];
 elseif (isset($_GET['num_tariffe_mostra'])) $num2 = (int) $_GET['num_tariffe_mostra'];
@@ -53,6 +64,13 @@ for ($num1 = 2 ; $num1 <= $num2 ; $num1++) {
 $var_pag[$n_var_pag++] = "numtariffa$num1";
 $var_pag[$n_var_pag++] = "tariffa_sel$num1";
 } # fine for $num1
+$num2 = opendir("./includes/lang/");
+while ($num1 = readdir($num2)) {
+if ($num1 != "." and $num1 != ".." and strlen($num1) <= 3 and preg_replace("/[a-z]/","",$num1) == "") {
+$var_pag[$n_var_pag++] = "n_descrizione_$num1";
+$var_pag[$n_var_pag++] = "n_commento_$num1";
+} # fine if ($num1 != "." and $num1 != ".." and...
+} # fine while ($num1 = readdir($num2))
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -296,7 +314,7 @@ if (!empty($azione)) {
 $mostra_tab_tariffe = "NO";
 
 
-if ($modificadescr and $priv_mod_tariffe != "n") {
+if (!empty($modificadescr) and $priv_mod_tariffe != "n") {
 $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 if (strcmp((string) $n_descrizione_ita,"")) {
@@ -326,13 +344,14 @@ closedir($lang_dir);
 echo "<br>".ucfirst(mex("descrizione della tariffa",$pag))." ".mex("aggiornata",$pag).".<br>";
 unlock_tabelle($tabelle_lock);
 $dest = "#descrcocont";
-} # fine if ($modificadescr and $priv_mod_tariffe != "n")
+} # fine if (!empty($modificadescr) and $priv_mod_tariffe != "n")
 
 
-if ($aggurlfoto and $priv_mod_tariffe != "n" and (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI")) {
+if (!empty($aggurlfoto) and $priv_mod_tariffe != "n" and (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZIONI_DEMO_ADMIN != "SI")) {
 $dest = "#aggfoto";
+$errore = "";
 if (@get_magic_quotes_gpc()) $n_urlfoto = stripslashes($n_urlfoto);
-$lowurl = strtolower($n_urlfoto);
+$lowurl = strtolower(fixstr($n_urlfoto));
 if (substr($lowurl,-4) != ".jpg" and substr($lowurl,-5) != ".jpeg" and substr($lowurl,-4) != ".gif" and substr($lowurl,-4) != ".png" and substr($lowurl,-5) != ".webp") $errore = "SI";
 if (str_replace("<","",$n_urlfoto) != $n_urlfoto or str_replace(">","",$n_urlfoto) != $n_urlfoto or str_replace("\"","",$n_urlfoto) != $n_urlfoto) $errore = "SI";
 if ($errore != "SI") {
@@ -349,10 +368,10 @@ unlock_tabelle($tabelle_lock);
 $dest = "#ultimafoto";
 } # fine if ($errore != "SI")
 else echo "".ucfirst(mex("l'url della foto è sbagliata",$pag)).".<br>";
-} # fine if ($aggurlfoto and $priv_mod_tariffe != "n" and...
+} # fine if (!empty($aggurlfoto) and $priv_mod_tariffe != "n" and...
 
 
-if ($commentofoto and $priv_mod_tariffe != "n") {
+if (!empty($commentofoto) and $priv_mod_tariffe != "n") {
 if ($numfoto and controlla_num_pos($numfoto) == "SI") {
 $tabelle_lock = array($tabledescrizioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
@@ -387,16 +406,16 @@ echo "<br>".ucfirst(mex("commento della foto",$pag))." $numfoto ".mex("aggiornat
 unlock_tabelle($tabelle_lock);
 } # fine if ($numfoto and controlla_num_pos($numfoto) == "SI") 
 $dest = "#fotocont";
-} # fine if ($commentofoto and $priv_mod_tariffe != "n")
+} # fine if (!empty($commentofoto) and $priv_mod_tariffe != "n")
 
 
-if ($cancurlfoto and $priv_mod_tariffe != "n") {
+if (!empty($cancurlfoto) and $priv_mod_tariffe != "n") {
 if ($numfoto and controlla_num_pos($numfoto) == "SI") {
 esegui_query("delete from $tabledescrizioni where nome = 'tariffa".$numtariffa1."' and (tipo = 'tarfoto' or tipo = 'tarcommfoto') and numero = '$numfoto' ");
 echo "".ucfirst(mex("foto eliminata",$pag)).".<br>";
 } # fine if ($numfoto and controlla_num_pos($numfoto) == "SI") 
 $dest = "#fotocont";
-} # fine if ($cancurlfoto and $priv_mod_tariffe != "n")
+} # fine if (!empty($cancurlfoto) and $priv_mod_tariffe != "n")
 
 
 echo "<br><div style=\"text-align: center;\">
@@ -441,7 +460,7 @@ $max_periodo = risul_query($periodi,(numlin_query($periodi) - 1),'idperiodi');
 if ($mostra_disp == "s") {
 unset($limiti_var);
 unset($profondita);
-unset($dati_app);
+$dati_app = array();
 unset($app_prenota_id);
 unset($app_orig_prenota_id);
 unset($inizio_prenota_id);
@@ -481,6 +500,12 @@ $app_orig_prenota_id = $app_prenota_id;
 } # fine if ($info_periodi_ag['numero'])
 } # fine if ($num_app_agenzia != 0)
 } # fine if ($mostra_disp == "s")
+else {
+$idapp = esegui_query("select idappartamenti from $tableappartamenti order by priorita ");
+$dati_app['totapp'] = numlin_query($idapp);
+$dati_app['lista'] = ",";
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) $dati_app['lista'] .= risul_query($idapp,$num1,'idappartamenti').",";
+} # fine if ($mostra_disp == "s")
 
 
 $app_regola2_orig = array();
@@ -969,7 +994,7 @@ if ($tab_modificabile) echo "<br>";
 
 $select_tariffe = "";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI") {
+if ($attiva_tariffe_consentite == "n" or (isset($tariffe_consentite_vett[$numtariffa]) and $tariffe_consentite_vett[$numtariffa] == "SI")) {
 $presente = "NO";
 for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) if (${"numtariffa".$num2} == $numtariffa) $presente = "SI";
 if ($presente == "NO") {
@@ -1010,16 +1035,10 @@ if (!empty($dati_r2[$tariffa[1]])) {
 $num_app = explode(",",$dati_r2[$tariffa[1]]);
 $num_app = count($num_app);
 } # fine if (!empty($dati_r2[$tariffa[1]]))
-else {
-if ($dati_app) $num_app = $dati_app['totapp'];
-else {
-$num_app = esegui_query("select idappartamenti from $tableappartamenti ");
-$num_app = numlin_query($num_app);
-} # fine else if ($dati_app)
-} # fine else if (!empty($dati_r2[$tariffa[1]]))
+else $num_app = $dati_app['totapp'];
 if (isset($dati_r2['napp'][$tariffa[1]]) and $dati_r2['napp'][$tariffa[1]] > 1) {
 echo "<em><b>".$dati_r2['napp'][$tariffa[1]]."</b> ";
-if ($dati_r2['napp']['v'][$tariffa[1]]) echo strtolower(mex("Appartamenti vicini",'unit.php'));
+if (!empty($dati_r2['napp']['v'][$tariffa[1]])) echo strtolower(mex("Appartamenti vicini",'unit.php'));
 else echo mex("appartamenti",'unit.php');
 echo "</em>"." ".mex("tra",'crearegole.php')." ";
 } # fine if (isset($dati_r2['napp'][$tariffa[1]]) and $dati_r2['napp'][$tariffa[1]] > 1)
