@@ -53,7 +53,10 @@ $var_pag[21] = 'tableprenota_da_aggiornare';
 $var_pag[22] = 'torna_indietro';
 $var_pag[23] = 'dati_prn';
 $var_pag[24] = 'tipo_sposta';
-$n_var_pag = 25;
+$var_pag[25] = 'show_bar';
+$var_pag[26] = 'origine_vecchia';
+$var_pag[27] = 'indietro';
+$n_var_pag = 28;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -1418,7 +1421,7 @@ $max_contr = esegui_query("select max(numero) from $tablecontratti where tipo $L
 $max_contr = risul_query($max_contr,0,0);
 $option_num_contr = "";
 for ($num_contratto = 1 ; $num_contratto <= $max_contr ; $num_contratto++) {
-if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contratto] == "SI") {
+if ($attiva_contratti_consentiti == "n" or (isset($contratti_consentiti_vett[$num_contratto]) and $contratti_consentiti_vett[$num_contratto] == "SI")) {
 if (isset($nome_contratto[$num_contratto])) $num_contratto_vedi = $nome_contratto[$num_contratto];
 else $num_contratto_vedi = $num_contratto;
 $option_num_contr .= "<option value=\"$num_contratto\">$num_contratto_vedi</option>";
