@@ -27,7 +27,10 @@ $var_pag = array();
 $var_pag[0] = 'mese';
 $var_pag[1] = 'anno_succ';
 $var_pag[2] = 'tutti_mesi';
-$n_var_pag = 3;
+$var_pag[3] = 'show_bar';
+$var_pag[4] = 'tipo_tabella';
+$var_pag[5] = 'torna_indietro';
+$n_var_pag = 6;
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
