@@ -195,8 +195,9 @@ rendi_link(val_cal,n1,lista_d,ncal);
 function replica_tasti () {
 var tasto_mod = document.getElementById('modi');
 var tasto_ins = document.getElementById('inse');
+var tasto_giu = document.getElementById('bott');
+if (tasto_mod || tasto_ins || tasto_giu) {
 var lista_con = document.getElementById('lcon');
-if (tasto_mod || tasto_ins) {
 var tasto_can = document.getElementById('canc');
 var tasto_ind = document.getElementById('indi');
 var topsp = document.getElementById('topsp');
@@ -211,7 +212,16 @@ iLeft += elementi.offsetLeft;
 elementi = elementi.offsetParent;
 }
 
-var nuovo_html = '<div id="aziobar" style="text-align: right; width: 96%; padding: 0; z-index: 2; position: absolute; top: '+(iTop + 1)+'px; left: '+iLeft+'px;"><div style="float: right; background-color: #ffffff; padding: 1px;">';
+var pos_azb = 'absolute';
+var top_azb = (iTop + 1)+'px';
+if ( /Android|webOS|iPhone|iPad|iPod|BlackBerry|Mobile|Opera Mini/i.test(navigator.userAgent) ) {
+topsp.style.top = '2px';
+topsp.style.position = 'sticky';
+pos_azb = 'relative';
+top_azb = '0';
+}
+
+var nuovo_html = '<div id="aziobar" style="text-align: right; width: 96%; padding: 0; z-index: 2; position: '+pos_azb+'; top: '+top_azb+'; left: '+iLeft+'px;"><div style="float: right; background-color: #ffffff; padding: 1px;">';
 if (tasto_ins) {
 if (tasto_ins.value) tasto_ins = tasto_ins.value;
 else tasto_ins = tasto_ins.childNodes[0].innerHTML;
@@ -238,6 +248,11 @@ nuovo_html += '<option value="'+lista_con.options[n1].value+'">'+lista_con.optio
 } // fine for n1
 nuovo_html += '</select>';
 } // fine if (lista_con)
+if (tasto_giu) {
+tasto_giu = tasto_giu.childNodes[0].innerHTML;
+if (tasto_ins || tasto_mod) nuovo_html += '&nbsp;&nbsp;';
+nuovo_html += '<input class="rbutton" type="submit" onclick="location.hash=\'#bottom\';" value="&nbsp;'+tasto_giu+'&nbsp;">';
+}
 if (tasto_ind) {
 if ((tasto_ins || tasto_mod) && lista_con) nuovo_html += '<span class="canc_vsmlscr">';
 if (tasto_ind.value) tasto_ind = tasto_ind.value;
@@ -277,7 +292,7 @@ var nuova_lista_mod = '';
 var nuova_lista_contr = '';
 var tabelle = document.getElementsByTagName('table');
 for (n0 = 0 ; n0 < tabelle.length ; n0++) {
-if (tabelle[n0].className == 't1') {
+if (tabelle[n0].className == 't1' || tabelle[n0].className.substr(0,3) == 't1 ') {
 var righe = tabelle[n0].getElementsByTagName('tr');
 for (n1 = 1 ; n1 < (righe.length - 1) ; n1++) {
 cbox = righe[n1].getElementsByTagName('input');
@@ -319,7 +334,7 @@ var caselle = '';
 var cbox = '';
 var tabelle = document.getElementsByTagName('table');
 for (n0 = 0 ; n0 < tabelle.length ; n0++) {
-if (tabelle[n0].className == 't1') {
+if (tabelle[n0].className == 't1' || tabelle[n0].className.substr(0,3) == 't1 ') {
 var righe = tabelle[n0].getElementsByTagName('tr');
 for (n1 = 1 ; n1 < (righe.length - 1) ; n1++) {
 cbox = righe[n1].getElementsByTagName('input');
@@ -346,7 +361,7 @@ var n2 = 0;
 var caselle = '';
 var tabelle = document.getElementsByTagName('table');
 for (n0 = 0 ; n0 < tabelle.length ; n0++) {
-if (tabelle[n0].className == 't1') {
+if (tabelle[n0].className == 't1' || tabelle[n0].className.substr(0,3) == 't1 ') {
 var righe = tabelle[n0].getElementsByTagName('tr');
 for (n1 = 1 ; n1 < (righe.length - 1) ; n1++) {
 caselle = righe[n1].getElementsByTagName('td');
@@ -403,9 +418,9 @@ function tab_in_container () {
 var tabs = document.getElementsByTagName('table');
 var maxtabwidth = tabs[0].offsetWidth;
 var navbarwidth = 0;
-if (tabs[0].className == 'nav_bar') navbarwidth = maxtabwidth;
+if (tabs[0].className == 'nav_bar' || tabs[0].className.substr(0,8) == 'nav_bar ') navbarwidth = maxtabwidth;
 for (n1 = 1 ; n1 < tabs.length ; n1++) {
-if (tabs[n1].offsetWidth > maxtabwidth && tabs[n1].parentNode.className != 'tab_cont' && tabs[n1].parentNode.parentNode.className != 'tab_cont' && tabs[n1].className != 'm1') maxtabwidth = tabs[n1].offsetWidth;
+if (tabs[n1].offsetWidth > maxtabwidth && tabs[n1].parentNode.className != 'tab_cont' && tabs[n1].parentNode.parentNode.className != 'tab_cont' && tabs[n1].className != 'm1' && tabs[n1].className.substr(0,3) != 'm1 ') maxtabwidth = tabs[n1].offsetWidth;
 } // for n1
 if (maxtabwidth > 300) {
 if (maxtabwidth != navbarwidth) maxtabwidth = maxtabwidth + 6;
