@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2015 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -68,13 +68,13 @@ tab_in_container();
 
 
 
-if ($start_time) {
+if (isset($start_time)) {
 $start_time = explode(" ",$start_time);
 $start_time = (double) $start_time[0] + (double) $start_time[1];
 $end_time = explode(" ",microtime());
 $end_time = (double) $end_time[0] + (double) $end_time[1];
 echo "<small><small>seconds: ".round(($end_time - $start_time),2)."</small></small>";
-} # fine if ($start_time)
+} # fine if (isset($start_time))
 
 echo "
 </body>
