@@ -96,15 +96,19 @@ if (empty($privilegi_annuali_utente)) $privilegi_annuali_utente = esegui_query("
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else $anno_utente_attivato = "SI";
 } # fine if (empty($anno_utente_attivato))
+if (!isset($modifica_pers)) $modifica_pers = "";
+if (!isset($inserimento_nuovi_clienti)) $inserimento_nuovi_clienti = "";
+if (!isset($modifica_clienti)) $modifica_clienti = "";
+if (!isset($vedi_clienti)) $vedi_clienti = "";
 if ($anno_utente_attivato == "SI") {
-if (!isset($privilegi_globali_utente)) $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
+if (empty($privilegi_globali_utente)) $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
 if (!isset($priv_mod_pers)) $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
-if (substr($priv_mod_pers,0,1) == "s" and !$modifica_pers) $modifica_pers = "SI";
+if (empty($modifica_pers) and substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
 if (!isset($priv_crea_backup)) $priv_crea_backup = substr($priv_mod_pers,1,1);
 if (!isset($priv_ins_clienti)) $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
-if (substr($priv_ins_clienti,0,1) != "s" and !$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "NO";
-if (substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p" and !$modifica_clienti) $modifica_clienti = "NO";
-if (substr($priv_ins_clienti,2,1) != "s" and substr($priv_ins_clienti,2,1) != "p" and !$vedi_clienti) $vedi_clienti = "NO";
+if (empty($inserimento_nuovi_clienti) and substr($priv_ins_clienti,0,1) != "s") $inserimento_nuovi_clienti = "NO";
+if (empty($modifica_clienti) and substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p") $modifica_clienti = "NO";
+if (empty($vedi_clienti) and substr($priv_ins_clienti,2,1) != "s" and substr($priv_ins_clienti,2,1) != "p") $vedi_clienti = "NO";
 if (!isset($priv_ins_prenota)) $priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
 if (!isset($priv_ins_nuove_prenota)) $priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
 if (!isset($priv_ins_costi)) $priv_ins_costi = risul_query($privilegi_annuali_utente,0,'priv_ins_costi');
