@@ -49,7 +49,9 @@ $var_pag[20] = 'numero_email';
 $var_pag[21] = 'tariffa_selezionata';
 $var_pag[22] = 'num_tariffe_passa';
 $var_pag[23] = 'num_all_passa';
-$n_var_pag = 24;
+$var_pag[24] = 'testo_email_richiesta';
+$var_pag[25] = 'num_cat_pers_passa';
+$n_var_pag = 26;
 $num2 = 1;
 if (isset($_POST['num_ripeti'])) $num2 = (int) $_POST['num_ripeti'];
 elseif (isset($_GET['num_ripeti'])) $num2 = (int) $_GET['num_ripeti'];
@@ -102,6 +104,9 @@ $var_pag[$n_var_pag++] = "tariffesettimanali_$num1";
 $var_pag[$n_var_pag++] = "percentuale_tasse_tariffa_$num1";
 $var_pag[$n_var_pag++] = "sconto_$num1";
 $var_pag[$n_var_pag++] = "caparra_$num1";
+$var_pag[$n_var_pag++] = "valuta_caparra_$num1";
+$var_pag[$n_var_pag++] = "tasso_cambio_caparra_$num1";
+$var_pag[$n_var_pag++] = "valore_valuta_caparra_$num1";
 $var_pag[$n_var_pag++] = "commissioni_$num1";
 $var_pag[$n_var_pag++] = "num_persone_$num1";
 $var_pag[$n_var_pag++] = "unita_occupata_$num1";
@@ -124,7 +129,13 @@ $var_pag[$n_var_pag++] = "promemoria_entrata_$num1";
 $var_pag[$n_var_pag++] = "promemoria_uscita_$num1";
 $var_pag[$n_var_pag++] = "metodo_pagamento_caparra_$num1";
 $var_pag[$n_var_pag++] = "num_costi_aggiuntivi_$num1";
+$var_pag[$n_var_pag++] = "num_campi_pers_passa_$num1";
 $var_pag[$n_var_pag++] = "num_comm_pers_passa_$num1";
+$var_pag[$n_var_pag++] = "valuta_tariffa_$num1";
+$var_pag[$n_var_pag++] = "tasso_cambio_tariffa_$num1";
+$var_pag[$n_var_pag++] = "costo_valuta_tariffa_$num1";
+$var_pag[$n_var_pag++] = "valore_valuta_sconto_$num1";
+$var_pag[$n_var_pag++] = "costo_valuta_tot_$num1";
 $num4 = 0;
 if (isset($_POST["num_costi_aggiuntivi_$num1"])) $num4 = (int) $_POST["num_costi_aggiuntivi_$num1"];
 elseif (isset($_GET["num_costi_aggiuntivi_$num1"])) $num4 = (int) $_GET["num_costi_aggiuntivi_$num1"];
@@ -156,6 +167,16 @@ $var_pag[$n_var_pag++] = "tasso_cambio_paga$num3"."_$num1";
 $var_pag[$n_var_pag++] = "valore_valuta_paga$num3"."_$num1";
 } # fine for $num3
 $num4 = 0;
+if (isset($_POST["num_campi_pers_passa_$num1"])) $num4 = (int) $_POST["num_campi_pers_passa_$num1"];
+elseif (isset($_GET["num_campi_pers_passa_$num1"])) $num4 = (int) $_GET["num_campi_pers_passa_$num1"];
+for ($num3 = 0 ; $num3 < $num4 ; $num3++) {
+$var_pag[$n_var_pag++] = "nome_campo_pers_passa_$num3"."_$num1";
+$num5 = "";
+if (isset($_POST["nome_campo_pers_passa_$num3"."_$num1"])) $num5 = (string) $_POST["nome_campo_pers_passa_$num3"."_$num1"];
+elseif (isset($_GET["nome_campo_pers_passa_$num3"."_$num1"])) $num5 = (string) $_GET["nome_campo_pers_passa_$num3"."_$num1"];
+if (strcmp($num5,"")) $var_pag[$n_var_pag++] = "campo_personalizzato_$num5"."_$num1";
+} # fine for $num3
+$num4 = 0;
 if (isset($_POST["num_comm_pers_passa_$num1"])) $num4 = (int) $_POST["num_comm_pers_passa_$num1"];
 elseif (isset($_GET["num_comm_pers_passa_$num1"])) $num4 = (int) $_GET["num_comm_pers_passa_$num1"];
 for ($num3 = 0 ; $num3 < $num4 ; $num3++) {
@@ -170,6 +191,10 @@ if ($num2 == 1) {
 $num2 = 0;
 if (isset($_POST['num_tariffe_passa'])) $num2 = (int) $_POST['num_tariffe_passa'];
 elseif (isset($_GET['num_tariffe_passa'])) $num2 = (int) $_GET['num_tariffe_passa'];
+if ($num2) {
+$num5 = 0;
+if (isset($_POST['num_cat_pers_passa'])) $num5 = (int) $_POST['num_cat_pers_passa'];
+elseif (isset($_GET['num_cat_pers_passa'])) $num5 = (int) $_GET['num_cat_pers_passa'];
 for ($num1 = 1 ; $num1 <= $num2 ; $num1++) {
 $var_pag[$n_var_pag++] = "c_tot_selez$num1"."_1";
 $var_pag[$n_var_pag++] = "n_tariffa_selez$num1"."_1";
@@ -194,7 +219,9 @@ $var_pag[$n_var_pag++] = "valore_giornaliero_max_costo_agg$num3"."_tsel$num1"."_
 $var_pag[$n_var_pag++] = "giorni_costo_agg$num3"."_tsel$num1"."_1";
 $var_pag[$n_var_pag++] = "tipo_persona_costo_agg$num3"."_tsel$num1"."_1";
 } # fine for $num3
+for ($num3 = 1 ; $num3 <= $num5 ; $num3++) $var_pag[$n_var_pag++] = "numpers_tipo_$num3"."_tariffa_selez$num1"."_1";
 } # fine for $num1
+} # fine if ($num2)
 } # fine ($num2 == 1)
 $num2 = 0;
 if (isset($_POST['numero_email'])) $num2 = (int) $_POST['numero_email'];
@@ -588,7 +615,7 @@ unlock_tabelle($tabelle_lock);
 } # fine if ($inviato['ok'])
 else {
 if (!empty($inviato['err'])) echo "<br>".htmlspecialchars($inviato['err'])."<br>";
-echo "<br>&nbsp;".mex("Non si è potuto inviare l'email a",$pag)." <b class=\"colred\">$destinatario_email</b>.<br>";
+echo "<br>&nbsp;".mex("Non si è potuto inviare l'email a",$pag)." <b class=\"colred\">".htmlspecialchars($destinatario_email)."</b>.<br>";
 } # fine else if ($inviato['ok'])
 } # fine if (!empty(${"destinatario_email".$num1}) and strstr(${"destinatario_email".$num1},"@"))
 } # fine for $num1
